'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deleteSavedAddress = exports.getSavedAddress = exports.createNewCustomerAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

var _ChangeCase = require('../utility/ChangeCase');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all general Customer related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Create New Customer
 * @param {string} email
 * @param {string} password
 * @param {string} firstName
 * @param {string} lastName
 * @param {string} phone
 * @param {int} identityId
 * @param {string} coName
 * @param {string} coPhone
 * @param {string} coVatNo
 * @return {object} Promise resolve/reject
 */
var createNewCustomerAsync = exports.createNewCustomerAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(_ref) {
    var email = _ref.email,
        password = _ref.password,
        firstName = _ref.firstName,
        lastName = _ref.lastName,
        phone = _ref.phone,
        identityId = _ref.identityId,
        coName = _ref.coName,
        coPhone = _ref.coPhone,
        coVatNo = _ref.coVatNo,
        language = _ref.language;
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.NEW_CUSTOMER,
              headers: { 'Content-Type': 'application/json' },
              data: (0, _ChangeCase.camelToSnake)({
                email: email,
                password: password,
                firstName: firstName,
                lastName: lastName,
                phone: phone,
                identityId: identityId,
                companyName: coName,
                companyPhone: coPhone,
                companyVatNumber: coVatNo,
                userSettings: {
                  default_language_code: language
                }
              })
            });

          case 3:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function createNewCustomerAsync(_x) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Returns list of saved address
 * @param {object} params # {page, limit, customerId}
 * @param {string} token
 * @return {object} Promise resolve/reject
 */

var getSavedAddress = exports.getSavedAddress = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(params, token) {
    var routes;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.CUSTOMER_ADDRESS,
              headers: { Authorization: 'Bearer ' + token },
              params: params
            });

          case 3:
            routes = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(routes));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function getSavedAddress(_x2, _x3) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * delete saved address by address id
 * @param {string} customerAddressId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var deleteSavedAddress = exports.deleteSavedAddress = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(customerAddressId, token) {
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.CUSTOMER_ADDRESS + '/' + customerAddressId,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context3.abrupt('return', { data: true });

          case 6:
            _context3.prev = 6;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 9:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 6]]);
  }));

  return function deleteSavedAddress(_x4, _x5) {
    return _ref4.apply(this, arguments);
  };
}();