'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSelectedDriverRoutesAsync = exports.downloadDriverPaymentAsync = exports.updateDriverPaymentAsync = exports.createDriverPaymentAsync = exports.getDriverPaymentAsync = exports.getSearchedDrivers = exports.assignToFreelancer = exports.deleteDriversAsync = exports.categoriesCustomerDrivers = exports.categoriesCustomerDriversForCount = exports.getActiveStatusCountsAndTotalCounts = exports.iterateDriverArrays = exports.createDriverScheduleAsync = exports.deleteDriverScheduleAsync = exports.updateDriverScheduleAsync = exports.getUpdatedDriverLiveData = exports.getDriverRoutesAsync = exports.getDriverCountsAsync = exports.getDriversWithFiltersAsync = exports.getDriversBasedOnSearchResult = exports.updateDriverAsync = exports.getDriversAsync = exports.createDriverAsync = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

var _ChangeCase = require('../utility/ChangeCase');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Driver related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Create Driver
 * @typedef { Object } Window
 * @property {string} startTime ("HH:MM") Format
 * @property {string} endTime ("HH:MM") Format
 * @typedef { Object } Schedule
 * @property {number} transactionGroupId
 * @property {string} startAt (YYYY-MM-DD)
 * @property {boolean} isDefault // to set this Schedule as a default
 * @property {Array.<Window>} windows Array of window object
 * @property {Array.<number>} recursions Array of day numbers for recurring window
 * @typedef { Object } Driver
 * @property {Array.<number>} transactionGroupIds (mandatory)
 * @property {boolean} sendConfirmationSms (optional)
 * @property {boolean} sendConfirmationEmail (optional)
 * @property {Array.<number>} driverTypeIds (mandatory)
 * @property {string} firstName (mandatory)
 * @property {string} lastName (mandatory)
 * @property {string} email (mandatory)
 * @property {string} password (mandatory)
 * @property {string} birthday (mandatory) (Y-m-d)
 * @property {string} phone (mandatory)
 * @property {string} vehicleColor (optional)
 * @property {number} averageSpeed (optional)
 * @property {number} maximumCapacity (optional)
 * @property {number} vehicleModelYear (optional)
 * @property {string} vehicleLicenseNumber (optional)
 * @property {string} vehicleBrand (optional)
 * @property {string} vehicleModel (optional)
 * @property {number} vehicleTypeId (optional)
 * @property {Array.<Schedule>} schedules (optional) Array of schedule object
 * @param {Driver} driverInfo {}
 * @param {string} token
 * @return {Object} Promise resolve/reject
 */
var createDriverAsync = exports.createDriverAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(_ref, token) {
    var transactionGroupIds = _ref.transactionGroupIds,
        _ref$sendConfirmation = _ref.sendConfirmationSms,
        sendConfirmationSms = _ref$sendConfirmation === undefined ? false : _ref$sendConfirmation,
        _ref$sendConfirmation2 = _ref.sendConfirmationEmail,
        sendConfirmationEmail = _ref$sendConfirmation2 === undefined ? false : _ref$sendConfirmation2,
        driverTypeIds = _ref.driverTypeIds,
        firstName = _ref.firstName,
        lastName = _ref.lastName,
        email = _ref.email,
        password = _ref.password,
        birthday = _ref.birthday,
        phone = _ref.phone,
        vehicleColor = _ref.vehicleColor,
        averageSpeed = _ref.averageSpeed,
        maximumCapacity = _ref.maximumCapacity,
        vehicleModelYear = _ref.vehicleModelYear,
        vehicleLicenseNumber = _ref.vehicleLicenseNumber,
        vehicleBrand = _ref.vehicleBrand,
        vehicleModel = _ref.vehicleModel,
        vehicleTypeId = _ref.vehicleTypeId,
        schedules = _ref.schedules,
        _ref$interviewDetails = _ref.interviewDetails,
        interviewDetails = _ref$interviewDetails === undefined ? {} : _ref$interviewDetails,
        _ref$bank = _ref.bank,
        bank = _ref$bank === undefined ? {} : _ref$bank,
        identificationNumber = _ref.identificationNumber,
        serviceProviderDriverServiceIds = _ref.serviceProviderDriverServiceIds;
    var data, driver, response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            data = {
              transactionGroupIds: transactionGroupIds,
              sendConfirmationSms: sendConfirmationSms,
              sendConfirmationEmail: sendConfirmationEmail,
              driverTypeIds: driverTypeIds,
              firstName: firstName,
              lastName: lastName,
              email: email,
              password: password,
              birthday: birthday,
              phone: phone,
              vehicle: {
                vehicleColor: vehicleColor,
                averageSpeed: averageSpeed,
                maximumCapacity: maximumCapacity,
                vehicleModelYear: vehicleModelYear,
                vehicleLicenseNumber: vehicleLicenseNumber,
                vehicleBrand: vehicleBrand,
                vehicleModel: vehicleModel,
                vehicleTypeId: vehicleTypeId
              },
              schedules: schedules,
              interviewDetails: (0, _ChangeCase.camelToSnake)(interviewDetails),
              bank: (0, _ChangeCase.camelToSnake)(bank),
              identificationNumber: identificationNumber,
              serviceProviderDriverServiceIds: serviceProviderDriverServiceIds
            };
            driver = (0, _ChangeCase.camelToSnake)(_extends({}, data, {
              vehicle: (0, _ChangeCase.camelToSnake)(data.vehicle),
              schedules: data.schedules ? data.schedules.map(function (schedule) {
                var newSchedule = _extends({}, schedule, {
                  windows: schedule.windows.map(function (window) {
                    return (0, _ChangeCase.camelToSnake)(window);
                  })
                });
                return (0, _ChangeCase.camelToSnake)(newSchedule);
              }) : undefined
            }));
            _context.next = 5;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.CUSTOMER_DRIVER,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: driver
            });

          case 5:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 9:
            _context.prev = 9;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 12:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 9]]);
  }));

  return function createDriverAsync(_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Get Driver List
 * @param {object} filterObject {limit, page, driverIds}
 * limit (optional) (int)
 * page (optional) (int) #offset, start from 1 value
 * driverIds (optional) (csv)
 * @param {string} token
 * @return {promise} reject/resolve
 * Will return [] array if there"s no drivers
 */
var getDriversAsync = exports.getDriversAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2() {
    var filterObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var token = arguments[1];
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context2.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.DRIVER + '/' + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response));

          case 8:
            _context2.prev = 8;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 8]]);
  }));

  return function getDriversAsync() {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Update Driver
 * @typedef { Object } Window
 * @property {string} startTime ("HH:MM") Format
 * @property {string} endTime ("HH:MM") Format
 * @typedef {Object} Schedule
 * @property {number} transactionGroupId
 * @property {string} startAt (YYYY-MM-DD)
 * @property {boolean} isDefault // to set this Schedule as a default
 * @property {Array.<Window>} windows Array of window object
 * @property {Array.<number>} recursions Array of day numbers for recurring window
 * @typedef {Object} Driver
 * @property {number} id
 * @property {number} driverStatusId
 * @property {Array.<number>} transactionGroupIds
 * @property {Array.<number>} languageIds
 * @property {boolean} hasCriminalRecord
 * @property {boolean} isAProfessionalDriver
 * @property {boolean} hasWorkAsDriver
 * @property {string} referredFrom
 * @property {string} drivingReason
 * @property {string} remarks
 * @property {string} firstName
 * @property {string} lastName
 * @property {string} phone
 * @property {string} password
 * @property {string} passwordConfirmation
 * @property {number} vehicleModelYear
 * @property {number} averageSpeed
 * @property {number} maximumCapacity
 * @property {number} vehicleTypeId
 * @property {string} vehicleModel
 * @property {string} vehicleBrand
 * @property {string} vehicleLicenseNumber
 * @property {string} vehicleColor
 * @property {string} branchCode // bank branch code
 * @property {string} code // bank code
 * @property {string} name // bank name
 * @property {string} accountNumber // bank account number
 * @property {Array.<Schedule>} schedules  Array of schedule object
 * @param {Driver} driverDetailsInfo {}
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var updateDriverAsync = exports.updateDriverAsync = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(_ref4, params, token) {
    var id = _ref4.id,
        identificationNumber = _ref4.identificationNumber,
        driverStatusId = _ref4.driverStatusId,
        languageIds = _ref4.languageIds,
        transactionGroupIds = _ref4.transactionGroupIds,
        driverTypeIds = _ref4.driverTypeIds,
        firstName = _ref4.firstName,
        lastName = _ref4.lastName,
        phone = _ref4.phone,
        password = _ref4.password,
        passwordConfirmation = _ref4.passwordConfirmation,
        vehicleModelYear = _ref4.vehicleModelYear,
        averageSpeed = _ref4.averageSpeed,
        maximumCapacity = _ref4.maximumCapacity,
        vehicleTypeId = _ref4.vehicleTypeId,
        vehicleModel = _ref4.vehicleModel,
        vehicleBrand = _ref4.vehicleBrand,
        vehicleLicenseNumber = _ref4.vehicleLicenseNumber,
        vehicleColor = _ref4.vehicleColor,
        schedules = _ref4.schedules,
        _ref4$interviewDetail = _ref4.interviewDetails,
        interviewDetails = _ref4$interviewDetail === undefined ? {} : _ref4$interviewDetail,
        _ref4$bank = _ref4.bank,
        bank = _ref4$bank === undefined ? {} : _ref4$bank,
        serviceProviderDriverServiceIds = _ref4.serviceProviderDriverServiceIds;
    var driverInfo, response;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            driverInfo = (0, _ChangeCase.camelToSnake)({
              id: id,
              identificationNumber: identificationNumber,
              driverStatusId: driverStatusId,
              languageIds: languageIds,
              transactionGroupIds: transactionGroupIds,
              driverTypeIds: driverTypeIds,
              interviewDetails: (0, _ChangeCase.camelToSnake)(interviewDetails),
              user: (0, _ChangeCase.camelToSnake)({
                firstName: firstName,
                lastName: lastName,
                phone: phone,
                password: password,
                passwordConfirmation: passwordConfirmation
              }),
              vehicle: (0, _ChangeCase.camelToSnake)({
                vehicleModelYear: vehicleModelYear,
                averageSpeed: averageSpeed,
                maximumCapacity: maximumCapacity,
                vehicleTypeId: vehicleTypeId,
                vehicleModel: vehicleModel,
                vehicleBrand: vehicleBrand,
                vehicleLicenseNumber: vehicleLicenseNumber,
                vehicleColor: vehicleColor
              }),
              bank: (0, _ChangeCase.camelToSnake)(bank),
              schedules: schedules ? schedules.map(function (schedule) {
                var newSchedule = _extends({}, schedule, {
                  windows: schedule.windows.map(function (window) {
                    return (0, _ChangeCase.camelToSnake)(window);
                  })
                });
                return (0, _ChangeCase.camelToSnake)(newSchedule);
              }) : undefined,
              serviceProviderDriverServiceIds: serviceProviderDriverServiceIds
            });
            _context3.next = 4;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.DRIVER_UPDATE.replace('{0}', id),
              headers: { Authorization: 'Bearer ' + token },
              params: (0, _ChangeCase.camelToSnake)(params),
              data: driverInfo
            });

          case 4:
            response = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 11:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 8]]);
  }));

  return function updateDriverAsync(_x4, _x5, _x6) {
    return _ref5.apply(this, arguments);
  };
}();

/**
 * Retrieve specific driver based on the search result
 * @param {object} filterObject {limit, page}
 * limit (optional) (int)
 * page (optional) (int) #offset, start from 1 value
 * @param {array} searchResult
 * @param {string} token
 * @return {promise} reject/resolve
 * Will return [] array if there"s no drivers
 * @deprecated since version 0.1.77
 */
var getDriversBasedOnSearchResult = exports.getDriversBasedOnSearchResult = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(filterObject, searchResult, token) {
    var filedName, driverFilterFieldName, driverIds, driver;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            filedName = 'driver_id';
            driverFilterFieldName = 'id';
            // Manipulate the driversIds of Array Object into CSV string

            driverIds = (0, _Util.getCSVStringFromArrayObject)(searchResult, filedName);

            if (driverIds) {
              _context4.next = 6;
              break;
            }

            return _context4.abrupt('return', []);

          case 6:

            // filter the driver with search result ids
            filterObject[driverFilterFieldName] = driverIds;
            _context4.next = 9;
            return getDriversAsync(filterObject, token);

          case 9:
            driver = _context4.sent;
            return _context4.abrupt('return', driver);

          case 13:
            _context4.prev = 13;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.rejectPromise)(_context4.t0));

          case 16:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 13]]);
  }));

  return function getDriversBasedOnSearchResult(_x7, _x8, _x9) {
    return _ref6.apply(this, arguments);
  };
}();

/**
 * Get Driver with filters
 * @param {object} filterObject {jobRouteTypeIds, driverTypeIds, driverStatusId}
 * jobRouteTypeIds (string) (optinal) 1,2 #csv string
 * * 1 means Live, 2 means POD
 * driverTypeIds (string) (optinal) 1 #csv string
 * * 1 means Inhouse, 2 means Public, 3 means Service Provider
 * driverStatusIds (string) (optinal) 1,2,3,4 #csv string
 * * 1 means Active, 2 means With Route, 3 means Idle, 4 means Inactive driver
 * @param {int} customerId
 * @param {string} token
 * @param {boolean} validationStatus (optional)
 * @return {promise} reject/resolve
 * Will return [] array if there"s no drivers
 */
// TODO: needs unit testing
var getDriversWithFiltersAsync = exports.getDriversWithFiltersAsync = function () {
  var _ref7 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5() {
    var filterObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var customerId = arguments[1];
    var token = arguments[2];
    var validationStatus = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context5.prev = 1;
            _context5.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.CUSTOMER_DRIVERS.replace('{0}', customerId) + paramString.replace('&', '?'),
              headers: { Authorization: token }
            });

          case 4:
            response = _context5.sent;
            return _context5.abrupt('return', (0, _camelize2.default)(categoriesCustomerDrivers(response.data)));

          case 8:
            _context5.prev = 8;
            _context5.t0 = _context5['catch'](1);
            return _context5.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context5.t0));

          case 11:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[1, 8]]);
  }));

  return function getDriversWithFiltersAsync() {
    return _ref7.apply(this, arguments);
  };
}();

/**
 * Get Driver Counts for Dashboard including the driver data
 * @param {object} filterObject {jobRouteTypeIds, driverTypeIds, driverStatusId}
 * jobRouteTypeIds (string) (optinal) 1,2 #csv string
 * * 1 means Live, 2 means POD
 * driverTypeIds (array) (optinal) [1] #csv string
 * * 1 means Inhouse, 2 means Public, 3 means Service Provider
 * driverStatusIds (string) (optinal) 1,2,3,4 #csv string
 * * 1 means Active, 2 means With Route, 3 means Idle, 4 means Inactive driver
 * @param {string} customerId
 * @param {boolean} token (optional)
 * @return {promise} reject/resolve
 * Will return [] array if there"s no drivers
 */
// TODO: needs unit testing
var getDriverCountsAsync = exports.getDriverCountsAsync = function () {
  var _ref8 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6() {
    var filterObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var customerId = arguments[1];
    var token = arguments[2];
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context6.prev = 1;
            _context6.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.CUSTOMER_DRIVERS.replace('{0}', customerId) + paramString.replace('&', '?'),
              headers: { Authorization: token }
            });

          case 4:
            response = _context6.sent;
            return _context6.abrupt('return', calculateCustomerDriverCounts(response.data, filterObject.driverTypeIds));

          case 8:
            _context6.prev = 8;
            _context6.t0 = _context6['catch'](1);
            return _context6.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context6.t0));

          case 11:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[1, 8]]);
  }));

  return function getDriverCountsAsync() {
    return _ref8.apply(this, arguments);
  };
}();

/**
 * Get the Driver Routes
 * @param {object} filterObject # {pickupDate (mandatory), withAvailability, withSchedule, limit, offset}
 * pickupDate (optional)(string) = "2018-02-28"
 * withAvailability (optional)(int) = 1/0
 * withSchedule (optional)(int) = 1/0
 * limit = 20 (optional)(int)
 * page = 0 (optional)(int)
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
// TODO: needs unit testing
var getDriverRoutesAsync = exports.getDriverRoutesAsync = function () {
  var _ref9 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7(filterObject, token) {
    var paramString, routes;
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)((0, _ChangeCase.camelToSnake)(filterObject));
            _context7.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.DRIVER_ROUTE + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            routes = _context7.sent;
            return _context7.abrupt('return', (0, _camelize2.default)(routes));

          case 8:
            _context7.prev = 8;
            _context7.t0 = _context7['catch'](0);
            return _context7.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context7.t0));

          case 11:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined, [[0, 8]]);
  }));

  return function getDriverRoutesAsync(_x13, _x14) {
    return _ref9.apply(this, arguments);
  };
}();

/**
 * Get updated driver live data for Dashboard by comparing old payload with new
 * This function will calculate all of driver counts
 * @param {object} originalDriversObject
 * @param {string} pubSubPayload
 * @param {boolean} filterObject
 * @return {promise} reject/resolve
 * Will return [] array if there"s no drivers
 //TODO: Needs unit testing
 */
var getUpdatedDriverLiveData = exports.getUpdatedDriverLiveData = function getUpdatedDriverLiveData(originalDriversObject, pubSubPayload, filterObject) {
  try {
    pubSubPayload = (0, _camelize2.default)(pubSubPayload);
    pubSubPayload.payload.driverStatusId = pubSubPayload.payload.jobId > 0 ? 2 : 1;
    var payload = pubSubPayload.payload;
    var driverStatusIds = [1, 2, 3, 4];
    // 1 = Active Driver, 2 = With Route, 3 = Idle, 4 = Inactive driver
    var isValidStatus = driverStatusIds.includes(payload.driverStatusId);
    var isIncludeInStatusIds = true;
    if (filterObject.driverStatusIds) {
      isIncludeInStatusIds = filterObject.driverStatusIds.includes(payload.driverStatusId);
    }

    var isIncludeInDriverTypeIds = true;
    if (filterObject.driverTypeIds != null) {
      var hasDriverTypeId = payload.driverTypeIds.find(function (driverTypeId) {
        return filterObject.driverTypeIds.includes(driverTypeId);
      });

      isIncludeInDriverTypeIds = !!hasDriverTypeId;
    } else isIncludeInDriverTypeIds = true;

    if (!(isValidStatus && isIncludeInDriverTypeIds && isIncludeInStatusIds)) {
      return originalDriversObject;
    }

    var driverStatusKeys = Object.keys(originalDriversObject['data']);
    var matchedPayload = driverStatusKeys.reduce(function (matchedPayload, statusId) {
      var index = originalDriversObject['data'][statusId].findIndex(function (job) {
        return payload.driverId === parseInt(job.driverId); // order.driverId might be string/integer;
      });
      if (index >= 0) {
        matchedPayload.isDataExist = true;
        matchedPayload.statusId = statusId;
        matchedPayload.index = index;
        matchedPayload.data = originalDriversObject['data'][statusId][index];
      }
      return matchedPayload;
    }, { isDataExist: false, statusId: 0, index: -1, data: {} });

    if (matchedPayload.isDataExist) {
      // update activeStatusCounts
      originalDriversObject['activeStatusCounts'][payload.driverStatusId] += 1;
      var currentStatusCounts = originalDriversObject['activeStatusCounts'][matchedPayload.statusId];

      if (currentStatusCounts) {
        originalDriversObject['activeStatusCounts'][matchedPayload.statusId] -= 1;
      }

      originalDriversObject['data'][matchedPayload.statusId].splice(matchedPayload.index, 1);
    } else {
      originalDriversObject['totalStatusCounts'] += 1;
      filterObject.driverTypeIds.map(function (driverTypeId) {
        originalDriversObject['driverTypeCounts'][driverTypeId] += 1;
      });
      originalDriversObject['activeStatusCounts'][payload.driverStatusId] += 1;
    }
    // update data Object
    originalDriversObject['data'][payload.driverStatusId].push(payload);
    return originalDriversObject;
  } catch (e) {
    return {
      statusCode: '500',
      statusText: 'Error in updating job live data'
    };
  }
};

/** Update driver time slot
 * @param {int} scheduleId
 * @typedef {Object} ScheduleInfo
 * @property {number} driverId
 * @property {number} transactionGroupId
 * @property {string} startAt (YYYY-MM-DD)
 * @property {Array.<Window>} windows Array of window object
 * @property {Array.<number>} recursions Array of day numbers for recurring window
 * @param {ScheduleInfo} payload // Schdule info object
 * @param {Object} params
 * @param {string} token {driverId, transactionGroupId, startTime, endTime, startDate}
 * @return {Object} Promise resolve/reject
 * If resolve, return value: boolean(To indicate update successful or failed)
 * remarks: the API endpoint will return one of the following status:
 * 400: Validation Error
 * 400: Driver Schedule with same values exists
 * 200: Success
 */
var updateDriverScheduleAsync = exports.updateDriverScheduleAsync = function () {
  var _ref10 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8(scheduleId) {
    var payload = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var token = arguments[3];
    var newPayload, result;
    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _context8.prev = 0;
            newPayload = _extends({}, payload, {
              windows: payload.windows ? payload.windows.map(function (window) {
                return (0, _ChangeCase.camelToSnake)(window);
              }) : undefined
            });
            _context8.next = 4;
            return (0, _axios2.default)({
              method: 'put',
              url: '' + _Endpoint2.default.API_V3.DRIVER_SCHEDULE.replace('{0}', scheduleId),
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _ChangeCase.camelToSnake)(newPayload),
              params: (0, _ChangeCase.camelToSnake)(params)
            });

          case 4:
            result = _context8.sent;
            return _context8.abrupt('return', (0, _camelize2.default)(result.data));

          case 8:
            _context8.prev = 8;
            _context8.t0 = _context8['catch'](0);
            return _context8.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context8.t0));

          case 11:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined, [[0, 8]]);
  }));

  return function updateDriverScheduleAsync(_x17) {
    return _ref10.apply(this, arguments);
  };
}();

/** deleteDriverScheduleAsync
 * @param {int} scheduleId
 * @param {string} token
 * @return {object} Promise resolve/reject
 * return value: boolean(To indicate delete successful or failed)
 * remarks: the API endpoint will return one of the following status:
 * 404: Driver Schedule does not exists
 * 204: Success with no content
 */
var deleteDriverScheduleAsync = exports.deleteDriverScheduleAsync = function () {
  var _ref11 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9(scheduleId, token) {
    return regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.prev = 0;
            _context9.next = 3;
            return (0, _axios2.default)({
              method: 'delete',
              url: '' + _Endpoint2.default.API_V3.DRIVER_SCHEDULE.replace('{0}', scheduleId),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context9.abrupt('return', { data: true });

          case 6:
            _context9.prev = 6;
            _context9.t0 = _context9['catch'](0);
            return _context9.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context9.t0));

          case 9:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined, [[0, 6]]);
  }));

  return function deleteDriverScheduleAsync(_x18, _x19) {
    return _ref11.apply(this, arguments);
  };
}();

/** Add new driver time slot
 * @typedef {Object} ScheduleInfo
 * @property {number} driverId (mandatory)
 * @property {number} transactionGroupId (mandatory)
 * @property {string} startAt (YYYY-MM-DD) (mandatory)
 * @property {Array.<Window>} windows Array of window object (mandatory)
 * @property {Array.<number>} recursions Array of day numbers for recurring window
 * @param {ScheduleInfo} payload // Schdule info object
 * @param {Object} params url params
 * @param {string} token resolve/reject
 * @return {Object} Promise resolve/reject
 * If resolve, return value: boolean(To indicate update successful or failed)
 * remarks: the API endpoint will return one of the following status:
 * 400: Validation Error
 * 400: Driver Schedule with same values exists
 * 200: Success
 */
var createDriverScheduleAsync = exports.createDriverScheduleAsync = function () {
  var _ref12 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10() {
    var payload = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var params = arguments[1];
    var token = arguments[2];
    var newPayload, result;
    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _context10.prev = 0;
            newPayload = _extends({}, payload, {
              windows: payload.windows ? payload.windows.map(function (window) {
                return (0, _ChangeCase.camelToSnake)(window);
              }) : undefined
            });
            _context10.next = 4;
            return (0, _axios2.default)({
              method: 'post',
              url: '' + _Endpoint2.default.API_V3.DRIVER_SCHEDULE.replace('{0}', ''),
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _ChangeCase.camelToSnake)(newPayload),
              params: (0, _ChangeCase.camelToSnake)(params)
            });

          case 4:
            result = _context10.sent;
            return _context10.abrupt('return', (0, _camelize2.default)(result.data));

          case 8:
            _context10.prev = 8;
            _context10.t0 = _context10['catch'](0);
            return _context10.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context10.t0));

          case 11:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined, [[0, 8]]);
  }));

  return function createDriverScheduleAsync() {
    return _ref12.apply(this, arguments);
  };
}();

/**
 * Calculate Customer Driver Counts
 * @param {object} data
 * @param {array} driverTypeIds
 * @return {object} total count object of live driver data
 // TODO: needs unit testing
 */
function calculateCustomerDriverCounts(data, driverTypeIds) {
  var countData = {
    totalStatusCounts: 0,
    activeStatusCounts: { 1: 0, 2: 0, 3: 0, 4: 0 },
    driverTypeCounts: { 1: 0, 2: 0, 3: 0 }
  };

  var drivers = categoriesCustomerDriversForCount(data);
  return (0, _Util.arrayReduce)(Object.keys(drivers.data), iterateDriverArrays.bind(null, drivers, driverTypeIds), countData);
}

/** Dependency function of calculateCustomerDriverCounts
 * Calculate Customer Driver Counts
 * @param {object} drivers
 * @param {array} driverTypeIds
 * @param {object} counts #{driverTypeCounts, activeStatusCounts, totalStatusCounts}
 driverTypeCounts: (int) 10,
 activeStatusCounts: (object) {1: 0, 2: 1, 3: 0, 4: 2}
 totalStatusCounts: (int) 20
 * @param {int} value
 * @return {object} promise reject/resolve
 */
var iterateDriverArrays = exports.iterateDriverArrays = function iterateDriverArrays(drivers, driverTypeIds, counts, value) {
  (0, _Util.arrayReduce)(Object.keys(drivers.data[value]), getActiveStatusCountsAndTotalCounts.bind(null, drivers, driverTypeIds, value, counts));
  return counts;
};

/** Dependency function of calculateCustomerDriverCounts
 * Categories Customer Drivers for Count
 * @param {object} drivers
 * @param {array} driverTypeIds # [1,2,3]
 * @param {int} value # actual filter value 2
 * @param {object} counts
 * @param {int} currentVal passed from reducers function
 This counts will be increased values
 Example
 driverTypeCounts: 10,
 activeStatusCounts: {
  1: 10,
  2: 10,
  3: 10,
  4: 10,
 }
 totalStatusCounts: 10
 * @param {string} key #iteration key
*/
var getActiveStatusCountsAndTotalCounts = exports.getActiveStatusCountsAndTotalCounts = function getActiveStatusCountsAndTotalCounts(drivers, driverTypeIds, value, counts, currentVal, key) {
  var count = drivers.data[value][key].length;
  driverTypeIds.forEach(function (driverTypeId) {
    if (driverTypeId == value) {
      counts.activeStatusCounts[key] += count;
      counts.totalStatusCounts += count;
    }
  });
  counts.driverTypeCounts[value] += count;
};

/** Dependency function of calculateCustomerDriverCounts
 * Categories Customer Drivers for Count
 * @param {object} drivers
 * @return {object} drivers
 Example Response
 {
   1: {1: [], 2: [], 3: [], 4: []},
   2: {1: [], 2: [], 3: [], 4: []},
   3: {1: [], 2: [], 3: [], 4: []},
 };
 */
var categoriesCustomerDriversForCount = exports.categoriesCustomerDriversForCount = function categoriesCustomerDriversForCount(drivers) {
  var responseData = {
    1: { 1: [], 2: [], 3: [], 4: [] },
    2: { 1: [], 2: [], 3: [], 4: [] },
    3: { 1: [], 2: [], 3: [], 4: [] }
  };
  return {
    data: drivers['data'].reduce(function (data, value) {
      value.driver_type_ids.forEach(function (v, k) {
        if (data[v][value.driver_status_id]) {
          data[v][value.driver_status_id].push(value);
        }
      });
      return data;
    }, responseData)
  };
};

/** Dependency function of calculateCustomerDriverCounts
 * Categories Customer Drivers
 * @param {object} drivers
 * @return {object} drivers
 Example Response
 {
    1: [], 2: [], 3: [], 4: []
 };
 */
var categoriesCustomerDrivers = exports.categoriesCustomerDrivers = function categoriesCustomerDrivers(drivers) {
  var responseData = { 1: [], 2: [], 3: [], 4: [] };
  return {
    data: drivers['data'].reduce(function (data, value) {
      if (data[value.driver_status_id]) {
        data[value.driver_status_id].push(value);
      }
      return data;
    }, responseData)
  };
};

/**
 * delete Drivers
 * @param {string} driverIds Comma separated values of IDs belonging to drivers to remove. Only In-house drivers can be deleted. Example: ?driver_ids=1,2,3
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var deleteDriversAsync = exports.deleteDriversAsync = function () {
  var _ref13 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11(driverIds, token) {
    return regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            _context11.prev = 0;
            _context11.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: '' + _Endpoint2.default.API_V3.DRIVER_UPDATE.replace('/{0}', '?driver_ids=' + driverIds),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context11.abrupt('return', { data: true });

          case 6:
            _context11.prev = 6;
            _context11.t0 = _context11['catch'](0);
            return _context11.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context11.t0));

          case 9:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined, [[0, 6]]);
  }));

  return function deleteDriversAsync(_x21, _x22) {
    return _ref13.apply(this, arguments);
  };
}();

/**
 * assign to freelance driver
 * @param {number} driverId
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var assignToFreelancer = exports.assignToFreelancer = function () {
  var _ref14 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee12(driverId, params, token) {
    var result;
    return regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            _context12.prev = 0;
            _context12.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: '' + _Endpoint2.default.API_V3.ASSIGN_TO_FREELANCER.replace('{0}', driverId),
              headers: { Authorization: 'Bearer ' + token },
              data: params
            });

          case 3:
            result = _context12.sent;
            return _context12.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context12.prev = 7;
            _context12.t0 = _context12['catch'](0);
            return _context12.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context12.t0));

          case 10:
          case 'end':
            return _context12.stop();
        }
      }
    }, _callee12, undefined, [[0, 7]]);
  }));

  return function assignToFreelancer(_x23, _x24, _x25) {
    return _ref14.apply(this, arguments);
  };
}();

/**
 * Get Searched Drivers
 * @param {object} params driver_status_id, driver_type_id, limit, offset
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getSearchedDrivers = exports.getSearchedDrivers = function () {
  var _ref15 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee13(params, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            _context13.prev = 0;
            _context13.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.DRIVER_SEARCH,
              headers: { Authorization: 'Bearer ' + token },
              params: params
            });

          case 3:
            response = _context13.sent;
            return _context13.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context13.prev = 7;
            _context13.t0 = _context13['catch'](0);
            return _context13.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context13.t0));

          case 10:
          case 'end':
            return _context13.stop();
        }
      }
    }, _callee13, undefined, [[0, 7]]);
  }));

  return function getSearchedDrivers(_x26, _x27) {
    return _ref15.apply(this, arguments);
  };
}();

/**
 * Get the Driver Payments
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getDriverPaymentAsync = exports.getDriverPaymentAsync = function () {
  var _ref16 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee14(token) {
    var res;
    return regeneratorRuntime.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            _context14.prev = 0;
            _context14.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.DRIVER_PAYMENT,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            res = _context14.sent;
            return _context14.abrupt('return', (0, _camelize2.default)(res.data));

          case 7:
            _context14.prev = 7;
            _context14.t0 = _context14['catch'](0);
            return _context14.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context14.t0));

          case 10:
          case 'end':
            return _context14.stop();
        }
      }
    }, _callee14, undefined, [[0, 7]]);
  }));

  return function getDriverPaymentAsync(_x28) {
    return _ref16.apply(this, arguments);
  };
}();

/**
 * Create Driver Payment Batch
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var createDriverPaymentAsync = exports.createDriverPaymentAsync = function () {
  var _ref17 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee15(token) {
    var res;
    return regeneratorRuntime.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            _context15.prev = 0;
            _context15.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: '' + _Endpoint2.default.API_V3.DRIVER_PAYMENT,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            res = _context15.sent;
            return _context15.abrupt('return', (0, _camelize2.default)(res.data));

          case 7:
            _context15.prev = 7;
            _context15.t0 = _context15['catch'](0);
            return _context15.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context15.t0));

          case 10:
          case 'end':
            return _context15.stop();
        }
      }
    }, _callee15, undefined, [[0, 7]]);
  }));

  return function createDriverPaymentAsync(_x29) {
    return _ref17.apply(this, arguments);
  };
}();

/**
 * Update Driver Payment Batch
 * @param {string} id
 * @param {object} payload {limit, page, driverIds}
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var updateDriverPaymentAsync = exports.updateDriverPaymentAsync = function () {
  var _ref18 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee16(id, payload, token) {
    var res;
    return regeneratorRuntime.wrap(function _callee16$(_context16) {
      while (1) {
        switch (_context16.prev = _context16.next) {
          case 0:
            _context16.prev = 0;
            _context16.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.DRIVER_PAYMENT + '/' + id,
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _ChangeCase.camelToSnake)(payload)
            });

          case 3:
            res = _context16.sent;
            return _context16.abrupt('return', (0, _camelize2.default)(res.data));

          case 7:
            _context16.prev = 7;
            _context16.t0 = _context16['catch'](0);
            return _context16.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context16.t0));

          case 10:
          case 'end':
            return _context16.stop();
        }
      }
    }, _callee16, undefined, [[0, 7]]);
  }));

  return function updateDriverPaymentAsync(_x30, _x31, _x32) {
    return _ref18.apply(this, arguments);
  };
}();

/**
 * Download Driver Payment Batch
 * @param {string} id
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var downloadDriverPaymentAsync = exports.downloadDriverPaymentAsync = function () {
  var _ref19 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee17(id, token) {
    var res;
    return regeneratorRuntime.wrap(function _callee17$(_context17) {
      while (1) {
        switch (_context17.prev = _context17.next) {
          case 0:
            _context17.prev = 0;
            _context17.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.DRIVER_PAYMENT + '/' + id + '/download',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            res = _context17.sent;
            return _context17.abrupt('return', (0, _camelize2.default)(res.data));

          case 7:
            _context17.prev = 7;
            _context17.t0 = _context17['catch'](0);
            return _context17.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context17.t0));

          case 10:
          case 'end':
            return _context17.stop();
        }
      }
    }, _callee17, undefined, [[0, 7]]);
  }));

  return function downloadDriverPaymentAsync(_x33, _x34) {
    return _ref19.apply(this, arguments);
  };
}();

/**
 * Get driver details
 * @param {string} driverId
 * @param {object} filterObject
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getSelectedDriverRoutesAsync = exports.getSelectedDriverRoutesAsync = function () {
  var _ref20 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee18(driverId, filterObject, token) {
    var paramString, routes;
    return regeneratorRuntime.wrap(function _callee18$(_context18) {
      while (1) {
        switch (_context18.prev = _context18.next) {
          case 0:
            _context18.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)((0, _ChangeCase.camelToSnake)(filterObject));
            _context18.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.DRIVER_ROUTE + '/' + driverId + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            routes = _context18.sent;
            return _context18.abrupt('return', (0, _camelize2.default)(routes.data));

          case 8:
            _context18.prev = 8;
            _context18.t0 = _context18['catch'](0);
            return _context18.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context18.t0));

          case 11:
          case 'end':
            return _context18.stop();
        }
      }
    }, _callee18, undefined, [[0, 8]]);
  }));

  return function getSelectedDriverRoutesAsync(_x35, _x36, _x37) {
    return _ref20.apply(this, arguments);
  };
}();