'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeDraftJobAsync = exports.getProofDownload = exports.cancelJobAsync = exports.removeJobsAsync = exports.createJobsAsync = exports.getUpdatedJobLiveData = exports.getJobsWithFiltersAsync = exports.categoriesCustomerJobs = exports.getJobsCountsAsync = exports.getRecommendedJobsAsync = exports.getJobSummaryAsync = exports.getJobDetailAsync = exports.getJobsAsync = exports.getJobTimelineAsync = exports.getJobDriverLocationsAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Job related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Get Job Driver Locations
 * @param {int} jobId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getJobDriverLocationsAsync = exports.getJobDriverLocationsAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(jobId, token) {
    var jobDriverLocations;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.JOB_DRIVER_LOCATIONS.replace('{0}', jobId),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            jobDriverLocations = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(jobDriverLocations));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function getJobDriverLocationsAsync(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Returns job timeline
 * @param {int} jobId
 * @param {string} token
 * @param {object} filterObject # {nextCursor, limit}
 * @return {object} Promise resolve/reject
 */

var getJobTimelineAsync = exports.getJobTimelineAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(jobId, token) {
    var filterObject = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var paramString, timeline;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context2.prev = 1;
            _context2.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.JOB_TIMELINE.replace('{0}', jobId).replace('{1}', paramString.replace('&', '?')),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            timeline = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(timeline.data));

          case 8:
            _context2.prev = 8;
            _context2.t0 = _context2['catch'](1);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[1, 8]]);
  }));

  return function getJobTimelineAsync(_x4, _x5) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Returns jobs created by the customer
 * @param {object} filterObject # {pickupDateStart, pickupDateEnd, transactionGroupIds, jobStatusIds, includes, page, limit}
 * @param {string} token
 * @return {object} Promise resolve/reject
 */

var getJobsAsync = exports.getJobsAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(token) {
    var filterObject = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var paramString, jobs;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context3.prev = 1;
            _context3.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.JOB.replace('{0}', paramString.replace('&', '?')),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            jobs = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(jobs.data));

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3['catch'](1);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 11:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[1, 8]]);
  }));

  return function getJobsAsync(_x7) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Get Job Detail
 * @param {int} jobId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getJobDetailAsync = exports.getJobDetailAsync = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(jobId, token) {
    var jobDetail;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.JOB.replace('{0}', jobId),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            jobDetail = _context4.sent;
            return _context4.abrupt('return', (0, _camelize2.default)(jobDetail.data));

          case 7:
            _context4.prev = 7;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 10:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 7]]);
  }));

  return function getJobDetailAsync(_x8, _x9) {
    return _ref4.apply(this, arguments);
  };
}();

/**
 * Get Job Summary
 * @param {int} jobId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getJobSummaryAsync = exports.getJobSummaryAsync = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(jobId, token) {
    var jobSummary;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.prev = 0;
            _context5.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.JOB.replace('{0}', jobId) + '/summary',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            jobSummary = _context5.sent;
            return _context5.abrupt('return', (0, _camelize2.default)(jobSummary.data));

          case 7:
            _context5.prev = 7;
            _context5.t0 = _context5['catch'](0);
            return _context5.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context5.t0));

          case 10:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[0, 7]]);
  }));

  return function getJobSummaryAsync(_x10, _x11) {
    return _ref5.apply(this, arguments);
  };
}();

/**
 * Get Recommended Jobs
 * @param {object} filterObject #{driverId, pickupDate, limit, offset}
 * @param {string} token
 * @return {object} Promise resolve/reject
 * @deprecated since version 0.1.77
 */
// TODO: needs unit testing
// TODO: there no such thing as Recommended Jobs? Should be deprecated?
var getRecommendedJobsAsync = exports.getRecommendedJobsAsync = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6() {
    var filterObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var token = arguments[1];
    var paramString, jobSummary;
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context6.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.RECOMMENDED_JOB + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            jobSummary = _context6.sent;
            return _context6.abrupt('return', (0, _camelize2.default)(jobSummary.data));

          case 8:
            _context6.prev = 8;
            _context6.t0 = _context6['catch'](0);
            return _context6.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context6.t0));

          case 11:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[0, 8]]);
  }));

  return function getRecommendedJobsAsync() {
    return _ref6.apply(this, arguments);
  };
}();

/**
 * Retrieve All Job Counts
 * @param {object} filterObject # {pickupDate}
 * pickupDate (optional)(string) = "2018-02-28"
 * @param {int} customerId
 * @param {string} token
 * @return {object} Promise resolve/reject
 * //TODO: needs unit testing
 */
var getJobsCountsAsync = exports.getJobsCountsAsync = function () {
  var _ref7 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7(filterObject, customerId, token) {
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context7.prev = 1;
            _context7.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.CUSTOMER_JOBS.replace('{0}', customerId) + paramString.replace('&', '?'),
              headers: { Authorization: token }
            });

          case 4:
            response = _context7.sent;
            return _context7.abrupt('return', calculateCustomerJobsCounts(response.data));

          case 8:
            _context7.prev = 8;
            _context7.t0 = _context7['catch'](1);
            return _context7.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context7.t0));

          case 11:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined, [[1, 8]]);
  }));

  return function getJobsCountsAsync(_x13, _x14, _x15) {
    return _ref7.apply(this, arguments);
  };
}();

/**
 * Calculate Customer jobs Counts
 * @param {object} data
 * @return {object} data # retrun count of data object
 //TODO: needs unit testing
 */
function calculateCustomerJobsCounts(data) {
  var jobs = categoriesCustomerJobs(data);
  var countData = { totalStatusCounts: 0, activeStatusCounts: {} };
  return Object.keys(jobs.data).reduce(function (counts, value) {
    counts.activeStatusCounts[value] = jobs.data[value].length;
    counts.totalStatusCounts += jobs.data[value].length;
    return counts;
  }, countData);
}

/**
 * Categories Customer Jobs
 * @param {object} jobs
 * @return {object} data
 */
var categoriesCustomerJobs = exports.categoriesCustomerJobs = function categoriesCustomerJobs(jobs) {
  var responseData = { 2: [], 5: [], 7: [], 9: [] };
  return {
    data: jobs['data'].reduce(function (data, value) {
      if (data[value.job_status_id]) {
        data[value.job_status_id].push(value);
      }
      return data;
    }, responseData)
  };
};

/**
 * Get Jobs with filters for Dashboard
 * @param {object} filterObject # {pickupDate (mandatory), jobStatusIds}
 * @param {int} customerId
 * @param {string} token
 * @param {boolean} validationStatus
 * pickupDate (optional)(string) = "2018-02-28"
 * jobStatusIds (optional)(int) = 1,2 (csv)
 * @return {object} Promise resolve/reject
 *  //TODO: needs unit testing
 */
var getJobsWithFiltersAsync = exports.getJobsWithFiltersAsync = function () {
  var _ref8 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8() {
    var filterObject = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var customerId = arguments[1];
    var token = arguments[2];
    var validationStatus = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)(filterObject);
            _context8.prev = 1;
            _context8.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.CUSTOMER_JOBS.replace('{0}', customerId) + paramString.replace('&', '?'),
              headers: { Authorization: token }
            });

          case 4:
            response = _context8.sent;
            return _context8.abrupt('return', (0, _camelize2.default)(categoriesCustomerJobs(response.data)));

          case 8:
            _context8.prev = 8;
            _context8.t0 = _context8['catch'](1);
            return _context8.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context8.t0));

          case 11:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined, [[1, 8]]);
  }));

  return function getJobsWithFiltersAsync() {
    return _ref8.apply(this, arguments);
  };
}();

/**
 * Get Updated Job Live Data for Dashboard
 * @param {object} originalJobDatum
 * @param {object} pubSubPayload
 * @param {string} filterObject {pickupDate, routeStatusIds, includeJobs limit, offset}
 * @return {object} Promise resolve/reject
 */
// TODO: needs unit testing
var getUpdatedJobLiveData = exports.getUpdatedJobLiveData = function getUpdatedJobLiveData(originalJobDatum, pubSubPayload, filterObject) {
  try {
    pubSubPayload = (0, _camelize2.default)(pubSubPayload.payload);
    // If jobStatusId is 1, change into 2. #laraval side will handle it later.
    var jobStatusIds = [2, 5, 7, 9];
    if (pubSubPayload.jobStatusId == 1) pubSubPayload.jobStatusId = 2;

    /* palyload jobStatusId must be includes in 2,5,7,9
      payload date should be the same with today date
      payload jobStatusId jobStatusIds must be one of jobStatusIds of filterObject
      Else send return orginal Job Data */
    var isValidStatus = jobStatusIds.includes(pubSubPayload.jobStatusId);
    var isSameDate = pubSubPayload.pickupDate === filterObject.pickupDate;
    var isInclude = filterObject.jobStatusIds ? filterObject.jobStatusIds.includes(pubSubPayload.jobStatusId) : true;

    if (!(isValidStatus && isSameDate && isInclude)) {
      return originalJobDatum;
    }

    var jobStatusKeys = Object.keys(originalJobDatum['data']);
    var matchedPayload = jobStatusKeys.reduce(function (matchedPayload, statusId) {
      var index = originalJobDatum['data'][statusId].findIndex(function (job) {
        return pubSubPayload.jobId == job.jobId; // jobId might be string/integer;
      });
      if (index >= 0) {
        matchedPayload.statusId = statusId;
        matchedPayload.index = index;
        matchedPayload.data = originalJobDatum['data'][statusId][index];
        matchedPayload.isDataExist = originalJobDatum['data'][statusId][index];
      }
      return matchedPayload;
    }, { isDataExist: false, statusId: 0, index: -1, data: {} });

    if (matchedPayload.isDataExist) {
      // update activeStatusCounts
      originalJobDatum['activeStatusCounts'][pubSubPayload.jobStatusId] += 1;
      var currentStatusCounts = originalJobDatum['activeStatusCounts'][matchedPayload.statusId];
      originalJobDatum['activeStatusCounts'][matchedPayload.statusId] -= currentStatusCounts ? 1 : 0;
      originalJobDatum['data'][matchedPayload.statusId].splice(matchedPayload.index, 1);
    } else {
      originalJobDatum['totalStatusCounts'] += 1;
      originalJobDatum['activeStatusCounts'][pubSubPayload.jobStatusId] += 1;
    }
    // update data Object
    originalJobDatum['data'][pubSubPayload.jobStatusId].push(pubSubPayload);
    return originalJobDatum;
  } catch (e) {
    return { statusCode: '500', statusText: 'Error in updating job live data' };
  }
};

/**
 * create Jobs
 * @param {string} routeIds comma separated string ex: 1234,3455
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var createJobsAsync = exports.createJobsAsync = function () {
  var _ref9 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9(routeIds, token) {
    var routes, promises, responses;
    return regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.prev = 0;
            routes = routeIds.split(',');
            promises = routes.map(function (id) {
              return (0, _axios2.default)({
                method: 'POST',
                url: _Endpoint2.default.API_V3.JOB_FROM_ROUTE,
                headers: { Authorization: 'Bearer ' + token },
                data: {
                  route_id: id
                }
              });
            });
            _context9.next = 5;
            return _axios2.default.all(promises);

          case 5:
            responses = _context9.sent;
            return _context9.abrupt('return', responses.map(function (res, index) {
              var returnObj = {
                routeId: routes[index],
                job: (0, _camelize2.default)(res.data).data
              };
              return returnObj;
            }));

          case 9:
            _context9.prev = 9;
            _context9.t0 = _context9['catch'](0);
            return _context9.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context9.t0));

          case 12:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined, [[0, 9]]);
  }));

  return function createJobsAsync(_x18, _x19) {
    return _ref9.apply(this, arguments);
  };
}();

/**
 * delete Jobs
 * @param {string} jobIds comma separated string ex: 1234,3455
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var removeJobsAsync = exports.removeJobsAsync = function () {
  var _ref10 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10(jobIds, token) {
    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _context10.prev = 0;
            _context10.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: '' + _Endpoint2.default.API_V3.JOB.replace('/{0}', '?job_ids=' + jobIds + '&cascade=1'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context10.abrupt('return', { data: true });

          case 6:
            _context10.prev = 6;
            _context10.t0 = _context10['catch'](0);
            return _context10.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context10.t0));

          case 9:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined, [[0, 6]]);
  }));

  return function removeJobsAsync(_x20, _x21) {
    return _ref10.apply(this, arguments);
  };
}();

/**
 * delete Jobs
 * @param {string} jobId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var cancelJobAsync = exports.cancelJobAsync = function () {
  var _ref11 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11(jobId, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            _context11.prev = 0;
            _context11.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: '' + _Endpoint2.default.API_V3.JOB.replace('/{0}', '/' + jobId),
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: {
                status_id: 4 // cancelled
              }
            });

          case 3:
            response = _context11.sent;
            return _context11.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context11.prev = 7;
            _context11.t0 = _context11['catch'](0);
            return _context11.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context11.t0));

          case 10:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined, [[0, 7]]);
  }));

  return function cancelJobAsync(_x22, _x23) {
    return _ref11.apply(this, arguments);
  };
}();

/**
 * get download proof
 * @param {string} jobId
 * @param {string} locationId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getProofDownload = exports.getProofDownload = function () {
  var _ref13 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee12(_ref12) {
    var jobId = _ref12.jobId,
        locationId = _ref12.locationId,
        token = _ref12.token;
    var response;
    return regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            _context12.prev = 0;
            _context12.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.JOB.replace('{0}', jobId) + '/location/' + locationId + '/proof/download',
              headers: { Authorization: 'Bearer ' + token },
              responseType: 'arraybuffer'
            });

          case 3:
            response = _context12.sent;
            return _context12.abrupt('return', response.data);

          case 7:
            _context12.prev = 7;
            _context12.t0 = _context12['catch'](0);
            return _context12.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context12.t0));

          case 10:
          case 'end':
            return _context12.stop();
        }
      }
    }, _callee12, undefined, [[0, 7]]);
  }));

  return function getProofDownload(_x24) {
    return _ref13.apply(this, arguments);
  };
}();

/**
 * delete Draft Job
 * @param {string} jobId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var removeDraftJobAsync = exports.removeDraftJobAsync = function () {
  var _ref15 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee13(_ref14) {
    var jobId = _ref14.jobId,
        token = _ref14.token;
    var response;
    return regeneratorRuntime.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            _context13.prev = 0;
            _context13.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.JOB.replace('{0}', jobId) + '/draft',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context13.sent;
            return _context13.abrupt('return', response.data);

          case 7:
            _context13.prev = 7;
            _context13.t0 = _context13['catch'](0);
            return _context13.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context13.t0));

          case 10:
          case 'end':
            return _context13.stop();
        }
      }
    }, _callee13, undefined, [[0, 7]]);
  }));

  return function removeDraftJobAsync(_x25) {
    return _ref15.apply(this, arguments);
  };
}();