'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateOrderQuoteAsync = exports.splitToMultipleOrder = exports.updateOrderStatus = exports.getOrderStatusReasonAsync = exports.deleteOrderDispatchAsync = exports.broadcastToFreelancers = exports.updateOrderDispatchTo3PL = exports.mergeLocationDataWithErrors = exports.groupOrders = exports.deleteAllOrdersAsync = exports.deleteOrdersAsync = exports.deleteOrderAsync = exports.editOrdersAsync = exports.editOrderSync = exports.editOrderAsync = exports.createServiceProviderOrderAsync = exports.createOrderAsync = exports.getUniquePickupAddressesAsync = exports.getErrorOrderContentsAsync = exports.getOrdersAsync = exports.getSearchOrdersAsync = exports.getRemainingOrdersAsync = exports.findDuplicateIndexes = exports.concatDuplicateObjects = exports.mergeOldAndNewOrderRecords = exports.getOrdersGroupByPickUpAddressAsync = exports.getOrdersBasedOnSearchResult = exports.getOrderAsync = exports.getUploadedOrderProgressionAsync = exports.fileUploadForOrderAsync = exports.getRemainingOrdersCountAsync = exports.getOrderUploadTemplateAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _formData = require('form-data');

var _formData2 = _interopRequireDefault(_formData);

var _ChangeCase = require('../utility/ChangeCase');

var _lodash = require('lodash.isempty');

var _lodash2 = _interopRequireDefault(_lodash);

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Order related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Get template for order upload
 * @param {string} pickupDate (optional)(string) = "2018-02-28"
 * @param {string} token
 * @return {object} file data
 */
var getOrderUploadTemplateAsync = exports.getOrderUploadTemplateAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(pickupDate, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.GROUPING_BATCH_TEMPLATE + '?date=' + pickupDate,
              responseType: 'blob',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context.sent;
            return _context.abrupt('return', response.data);

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function getOrderUploadTemplateAsync(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Retrieve Remaining Orders Count
 * @param {object} filterObject # {pickupDate, withJob}
 * pickupDate (mandatory)(string) = "2018-02-28"
 * withJob(optional)(int)
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getRemainingOrdersCountAsync = exports.getRemainingOrdersCountAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(filterObject, token) {
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            paramString = (0, _Util.convertObjectIntoURLString)((0, _ChangeCase.camelToSnake)(filterObject));
            _context2.prev = 1;
            _context2.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ORDER_COUNT + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context2.prev = 8;
            _context2.t0 = _context2['catch'](1);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 11:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[1, 8]]);
  }));

  return function getRemainingOrdersCountAsync(_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Upload Excel file for orders
 * @param {object} fileObject
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var fileUploadForOrderAsync = exports.fileUploadForOrderAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(fileObject, token) {
    var form, response;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            form = new _formData2.default();

            form.append('grouping_spreadsheet', fileObject);

            _context3.next = 5;
            return (0, _axios2.default)(_Endpoint2.default.API_V3.BATCH_FILE_UPLOAD, {
              method: 'POST',
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'multipart/form-data'
              },
              data: form
            });

          case 5:
            response = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(response.data));

          case 9:
            _context3.prev = 9;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 12:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 9]]);
  }));

  return function fileUploadForOrderAsync(_x5, _x6) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Check the progress of order file uploading process
 * @param {int} customerId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getUploadedOrderProgressionAsync = exports.getUploadedOrderProgressionAsync = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(customerId, token) {
    var response, result, updatedProgressData;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.GROUPING_BATCH_PROGRESSION,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context4.sent;
            result = (0, _camelize2.default)(response.data);
            updatedProgressData = {
              chunkProgression: 0,
              totalChunkProgression: 0,
              failedLocationCount: 0,
              groupingLocationIdsSuccess: []
            };


            if (response.status !== 204) {
              updatedProgressData = {
                chunkProgression: result.data.chunkProgressionCount,
                totalChunkProgression: result.data.totalLocationCount,
                failedLocationCount: result.data.failedLocationCount,
                groupingLocationIdsSuccess: []
              };
            }

            return _context4.abrupt('return', { data: updatedProgressData });

          case 10:
            _context4.prev = 10;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 13:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 10]]);
  }));

  return function getUploadedOrderProgressionAsync(_x7, _x8) {
    return _ref4.apply(this, arguments);
  };
}();

/**
 * Retrieve single order
 * @param {int} orderId
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 //TODO: needs more extensive unit testing
 */
var getOrderAsync = exports.getOrderAsync = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(orderId, params, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.prev = 0;
            _context5.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.ORDER + '/' + orderId,
              headers: { Authorization: 'Bearer ' + token },
              params: params
            });

          case 3:
            response = _context5.sent;
            return _context5.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context5.prev = 7;
            _context5.t0 = _context5['catch'](0);
            return _context5.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context5.t0));

          case 10:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[0, 7]]);
  }));

  return function getOrderAsync(_x9, _x10, _x11) {
    return _ref5.apply(this, arguments);
  };
}();

/**
 * Retrieve orders based on search result
 * @param {int} customerId
 * @param {object} filterObject {pickupDate, limit, offset}
 * pickupDate (optional)(string) = "2018-02-28"
 * limit = 20 (optional)(int)
 * offset = 0 (optional)(int)
 * @param {int} searchResult
 * @param {string} token
 * @return {object} Promise resolve/reject
 //TODO: deprecated not being used on front-end? If not, needs unit test
 */
var getOrdersBasedOnSearchResult = exports.getOrdersBasedOnSearchResult = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(customerId, filterObject, searchResult, token) {
    var filedName, orderFilterFieldName, groupingLocationIds, order;
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.prev = 0;
            filedName = 'groupingLocationId';
            orderFilterFieldName = 'groupingLocationIds';
            // Manipulate the groupingLocationIds of Array Object into CSV string

            groupingLocationIds = (0, _Util.getCSVStringFromArrayObject)(searchResult, filedName);

            if (groupingLocationIds) {
              _context6.next = 6;
              break;
            }

            return _context6.abrupt('return', []);

          case 6:

            // filter the order with groupingLocationIds
            filterObject[orderFilterFieldName] = groupingLocationIds;
            _context6.next = 9;
            return getOrdersGroupByPickUpAddressAsync(filterObject, customerId, token);

          case 9:
            order = _context6.sent;
            return _context6.abrupt('return', order);

          case 13:
            _context6.prev = 13;
            _context6.t0 = _context6['catch'](0);
            return _context6.abrupt('return', (0, _Util.rejectPromise)(_context6.t0));

          case 16:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[0, 13]]);
  }));

  return function getOrdersBasedOnSearchResult(_x12, _x13, _x14, _x15) {
    return _ref6.apply(this, arguments);
  };
}();

/**
 * Retrieve All Order Counts //TODO: is this description correct?
 * @param {object} filterObject # {pickupDate, limit, offset}
 * pickupDate (optional)(string) = "2018-02-28"
 * limit = 20 (optional)(int)
 * offset = 0 (optional)(int)
 * @param {int} customerId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getOrdersGroupByPickUpAddressAsync = exports.getOrdersGroupByPickUpAddressAsync = function () {
  var _ref7 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7(filterObject, customerId, token) {
    var statusId, orders, errorContents;
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.prev = 0;

            /* If there"s no statusId is passed.
             * Use 2 as default. It means validated orders
             */
            statusId = filterObject.statusIds || 2;
            _context7.next = 4;
            return getOrdersAsync(filterObject, token);

          case 4:
            orders = _context7.sent;
            errorContents = void 0;

            /* Check statusId whethere 4 or not
             * If statusId is 4, need to combine the response with error contents
             */

            if (!(statusId === 4)) {
              _context7.next = 10;
              break;
            }

            _context7.next = 9;
            return getErrorOrderContentsAsync(filterObject, token);

          case 9:
            errorContents = _context7.sent;

          case 10:
            return _context7.abrupt('return', groupOrders(orders, errorContents ? errorContents : null));

          case 13:
            _context7.prev = 13;
            _context7.t0 = _context7['catch'](0);
            return _context7.abrupt('return', (0, _Util.rejectPromise)(_context7.t0));

          case 16:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined, [[0, 13]]);
  }));

  return function getOrdersGroupByPickUpAddressAsync(_x16, _x17, _x18) {
    return _ref7.apply(this, arguments);
  };
}();

/**
//TODO: description is vague and not unit testing
 * Merge Order Records
 * @param {array} oldValues
 * @param {array} newValues
 * @return {object} Promise resolve/reject
 * Response merged order object
 */
var mergeOldAndNewOrderRecords = exports.mergeOldAndNewOrderRecords = function mergeOldAndNewOrderRecords(oldValues, newValues) {
  try {
    var duplicateIndexes = (0, _Util.arrayReduce)(oldValues, findDuplicateIndexes.bind(null, newValues));
    var result = (0, _Util.arrayMap)(duplicateIndexes, concatDuplicateObjects.bind(null, oldValues, newValues));
    return result.oldValues.concat(result.newValues);
  } catch (e) {
    return (0, _Util.rejectPromise)(e);
  }
};

/**
//TODO: description is vague and no unit tests
 * Merge Two Objects which has the same id
 * @param {object} oldValues
 * @param {object} newValues
 * @param {object} data
 */
var concatDuplicateObjects = exports.concatDuplicateObjects = function concatDuplicateObjects(oldValues, newValues, data) {
  oldValues[data.oldIndex]['jobs'] = oldValues[data.oldIndex]['jobs'].concat(newValues[data.newIndex]['jobs']);
  newValues.splice(data.newIndex, 1);
};

/**
//TODO: description is vague and no unit test
 * Find duplicate indexes
 * @param {object} newValues
 * @param {array} accumulator
 Example [{oldIndex: i, newIndex: index}]
 * @param {object} oldValues
 * @param {int} i # iterator
 * @return {object} Promise resolve/reject
 */
var findDuplicateIndexes = exports.findDuplicateIndexes = function findDuplicateIndexes(newValues, accumulator, oldValues, i) {
  var index = newValues.findIndex(_Util.hasSameObjectId.bind(null, oldValues));
  if (index >= 0) {
    accumulator.push({ oldIndex: i, newIndex: index });
  }
  return accumulator;
};

/**
 * Get Remaining Orders
 * @param {object} filterObject # {statusIds, pickupDate (mandatory), withJob, withDriver, withRoute, sort, limit, offset}
 * statusIds = 1/2/3/4. 1 for "pending", 2 for "validated", 3 for "grouped", 4 for "failed"
 * pickupDate (mandatory) = "2018-02-28"
 * withJob (optional) = 1 OR 0
 * driverId (optional) = 1234
 * sort (optional) = fieldName,asc OR desc
 * limit = 20 (optional)
 * offset = 0 (optional)
 * @param {string} token
 * @return {object} Promise resolve/reject
 //TODO: not sure if this function is still used by admin? / no unit tests
 */
var getRemainingOrdersAsync = exports.getRemainingOrdersAsync = function () {
  var _ref8 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8(filterObject, token) {
    var locations;
    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _context8.prev = 0;
            _context8.next = 3;
            return getOrdersAsync(filterObject, token);

          case 3:
            locations = _context8.sent;
            return _context8.abrupt('return', groupOrders(locations));

          case 7:
            _context8.prev = 7;
            _context8.t0 = _context8['catch'](0);
            return _context8.abrupt('return', (0, _Util.rejectPromise)(_context8.t0));

          case 10:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined, [[0, 7]]);
  }));

  return function getRemainingOrdersAsync(_x19, _x20) {
    return _ref8.apply(this, arguments);
  };
}();

/**
 * Get search orders
 * @param {object} filterObject # {pickupDate (mandatory), limit, offset}
 * pickupDate (optional)(string) = "2018-02-28"
 * limit = 20 (optional)(int)
 * page = 0 (optional)(int)
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getSearchOrdersAsync = exports.getSearchOrdersAsync = function () {
  var _ref9 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9(filterObject, token) {
    var filters, paramString, response;
    return regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.prev = 0;

            /*
              Add following filter for remaining order
              statusIds = 2; // Success Orders
              withRoute = 0; // Orders without routes
              withJob = 1; // Order should have included jobId
              include = "pickup_group,delivery_address"
              limit = 20
              offset = 0
            */

            filters = (0, _ChangeCase.camelToSnake)(filterObject);
            paramString = (0, _Util.convertObjectIntoURLString)(filters);
            _context9.next = 5;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ORDER_SEARCH + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 5:
            response = _context9.sent;
            return _context9.abrupt('return', (0, _camelize2.default)(response.data));

          case 9:
            _context9.prev = 9;
            _context9.t0 = _context9['catch'](0);
            return _context9.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context9.t0));

          case 12:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined, [[0, 9]]);
  }));

  return function getSearchOrdersAsync(_x21, _x22) {
    return _ref9.apply(this, arguments);
  };
}();

/**
 * Get orders
 * @param {object} filterObject # {pickupDate (mandatory), limit, offset}
 * pickupDate (optional)(string) = "2018-02-28"
 * limit = 20 (optional)(int)
 * page = 0 (optional)(int)
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getOrdersAsync = exports.getOrdersAsync = function () {
  var _ref10 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10(filterObject, token) {
    var filters, paramString, response;
    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _context10.prev = 0;

            /*
              Add following filter for remaining order
              statusIds = 2; // Success Orders
              withRoute = 0; // Orders without routes
              withJob = 1; // Order should have included jobId
              include = "pickup_group,delivery_address"
              limit = 20
              offset = 0
            */

            filters = (0, _ChangeCase.camelToSnake)(filterObject);
            paramString = (0, _Util.convertObjectIntoURLString)(filters);
            _context10.next = 5;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ORDER + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 5:
            response = _context10.sent;
            return _context10.abrupt('return', (0, _camelize2.default)(response.data));

          case 9:
            _context10.prev = 9;
            _context10.t0 = _context10['catch'](0);
            return _context10.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context10.t0));

          case 12:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined, [[0, 9]]);
  }));

  return function getOrdersAsync(_x23, _x24) {
    return _ref10.apply(this, arguments);
  };
}();

/**
 * Get upload order"s error contents from Dynamodb
 * @param {object} filterObject # {pickupDateStart (mandatory), pickupDateEnd (mandatory)}
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getErrorOrderContentsAsync = exports.getErrorOrderContentsAsync = function () {
  var _ref12 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11(_ref11, token) {
    var pickupDateStart = _ref11.pickupDateStart,
        pickupDateEnd = _ref11.pickupDateEnd;
    var response;
    return regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            _context11.prev = 0;
            _context11.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.ORDER_ERRORS + '/?pickup_date_start=' + pickupDateStart + '&pickup_date_end=' + pickupDateEnd,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context11.sent;
            return _context11.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context11.prev = 7;
            _context11.t0 = _context11['catch'](0);
            return _context11.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context11.t0));

          case 10:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined, [[0, 7]]);
  }));

  return function getErrorOrderContentsAsync(_x25, _x26) {
    return _ref12.apply(this, arguments);
  };
}();

/**
 * Get pickup group
 * @param {object} filterObject # {pickupDate (mandatory), withJob}
 * pickupDate (optional)(string) = "2018-02-28"
 * withJob (optional)(int) = 0
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getUniquePickupAddressesAsync = exports.getUniquePickupAddressesAsync = function () {
  var _ref13 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee12(filterObject, token) {
    var filters, paramString, response, result, pickupAddressList;
    return regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            _context12.prev = 0;
            filters = (0, _ChangeCase.camelToSnake)(filterObject);
            paramString = (0, _Util.convertObjectIntoURLString)(filters);
            _context12.next = 5;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.PICKUP_GROUP + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 5:
            response = _context12.sent;
            result = response.data ? (0, _camelize2.default)(response.data.data) : [];
            pickupAddressList = result.map(function (locationObject) {
              return {
                pickupGroupId: locationObject.id,
                pickupLocationAddress: locationObject.address.address
              };
            });
            return _context12.abrupt('return', { data: pickupAddressList });

          case 11:
            _context12.prev = 11;
            _context12.t0 = _context12['catch'](0);
            return _context12.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context12.t0));

          case 14:
          case 'end':
            return _context12.stop();
        }
      }
    }, _callee12, undefined, [[0, 11]]);
  }));

  return function getUniquePickupAddressesAsync(_x27, _x28) {
    return _ref13.apply(this, arguments);
  };
}();

/**
 * Create single order
 * @param {object} orderObject
 //TODO: this object is not complete, an order can have much more parameters
 {
   pickupLocationAddress: "22 Gim moh road",
   deliveryAddress: "Holland Close",
   pickupDate: "28-02-2018",
   pickupTimeWindow: "14:35-16:00",
   deliveryDate: "28-02-2018",
   deliveryTimeWindow: "17:00-17:00",
   driverEmailId: null,
   capacity: 10,
 },
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var createOrderAsync = exports.createOrderAsync = function () {
  var _ref14 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee13(orderObject, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee13$(_context13) {
      while (1) {
        switch (_context13.prev = _context13.next) {
          case 0:
            _context13.prev = 0;

            orderObject = (0, _ChangeCase.camelToSnake)(orderObject);
            _context13.next = 4;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.ORDER_CREATE,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: {
                order_data: orderObject
              }
            });

          case 4:
            response = _context13.sent;
            return _context13.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context13.prev = 8;
            _context13.t0 = _context13['catch'](0);
            return _context13.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context13.t0));

          case 11:
          case 'end':
            return _context13.stop();
        }
      }
    }, _callee13, undefined, [[0, 8]]);
  }));

  return function createOrderAsync(_x29, _x30) {
    return _ref14.apply(this, arguments);
  };
}();

/**
 * Create service provider single order
 * @param {object} orderObject
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var createServiceProviderOrderAsync = function () {
  var _ref15 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee14(orderObject, token) {
    var _orderObject, include, orderCustomerEmail, rest, response;

    return regeneratorRuntime.wrap(function _callee14$(_context14) {
      while (1) {
        switch (_context14.prev = _context14.next) {
          case 0:
            _context14.prev = 0;
            _orderObject = orderObject, include = _orderObject.include, orderCustomerEmail = _orderObject.orderCustomerEmail, rest = _objectWithoutProperties(_orderObject, ['include', 'orderCustomerEmail']);

            orderObject = (0, _ChangeCase.camelToSnake)(rest);
            _context14.next = 5;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER_ORDER,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: {
                order_data: orderObject,
                order_customer_email: orderCustomerEmail,
                include: include
              }
            });

          case 5:
            response = _context14.sent;
            return _context14.abrupt('return', (0, _camelize2.default)(response.data));

          case 9:
            _context14.prev = 9;
            _context14.t0 = _context14['catch'](0);
            return _context14.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context14.t0));

          case 12:
          case 'end':
            return _context14.stop();
        }
      }
    }, _callee14, undefined, [[0, 9]]);
  }));

  return function createServiceProviderOrderAsync(_x31, _x32) {
    return _ref15.apply(this, arguments);
  };
}();

/**
 * Edit single order
 * @param {int} orderId
 * @param {object} orderObject
 //TODO: this object is not complete, an order can have much more parameters
 {
   pickupLocationAddress: "22 Gim moh road",
   deliveryAddress: "Holland Close",
   pickupDate: "28-02-2018",
   pickupTimeWindow: "14:35-16:00",
   deliveryDate: "28-02-2018",
   deliveryTimeWindow: "17:00-17:00",
   driverEmailId: null,
   capacity: 10,
 },
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
exports.createServiceProviderOrderAsync = createServiceProviderOrderAsync;
var editOrderAsync = exports.editOrderAsync = function () {
  var _ref16 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee15(orderId, orderObject, token) {
    var updatedLocationDataObject, response;
    return regeneratorRuntime.wrap(function _callee15$(_context15) {
      while (1) {
        switch (_context15.prev = _context15.next) {
          case 0:
            _context15.prev = 0;
            updatedLocationDataObject = {
              order_data: (0, _ChangeCase.camelToSnake)(orderObject)
            };
            _context15.next = 4;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.ORDER + '/' + orderId,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: updatedLocationDataObject
            });

          case 4:
            response = _context15.sent;
            return _context15.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context15.prev = 8;
            _context15.t0 = _context15['catch'](0);
            return _context15.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context15.t0));

          case 11:
          case 'end':
            return _context15.stop();
        }
      }
    }, _callee15, undefined, [[0, 8]]);
  }));

  return function editOrderAsync(_x33, _x34, _x35) {
    return _ref16.apply(this, arguments);
  };
}();

/**
 * Edit single order (sync address)
 * @param {int} orderId
 * @param {object} orderObject
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var editOrderSync = exports.editOrderSync = function () {
  var _ref17 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee16(orderId, orderObject) {
    var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var token = arguments[3];
    var updatedLocationDataObject, response;
    return regeneratorRuntime.wrap(function _callee16$(_context16) {
      while (1) {
        switch (_context16.prev = _context16.next) {
          case 0:
            _context16.prev = 0;
            updatedLocationDataObject = {
              order_data: (0, _ChangeCase.camelToSnake)(orderObject)
            };
            _context16.next = 4;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.ORDER + '/' + orderId + '/sync',
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: updatedLocationDataObject,
              params: params
            });

          case 4:
            response = _context16.sent;
            return _context16.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context16.prev = 8;
            _context16.t0 = _context16['catch'](0);
            return _context16.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context16.t0));

          case 11:
          case 'end':
            return _context16.stop();
        }
      }
    }, _callee16, undefined, [[0, 8]]);
  }));

  return function editOrderSync(_x37, _x38) {
    return _ref17.apply(this, arguments);
  };
}();

/**
 * Edit multiple orders
 * @param {array} orderDataList
 //TODO: this object is not complete, an order can have much more parameters
 [
   {
     groupingLocationId: 27318,
     locationData: {
       pickupLocationAddress: "22 Gim moh road",
       deliveryAddress: "Holland Close",
       pickupDate: "28-02-2018",
       pickupTimeWindow: "14:35-16:00",
       deliveryDate: "28-02-2018",
       deliveryTimeWindow: "17:00-17:00",
       driverEmailId: null,
       capacity: 10,
     },
   },
 ]
 * @param {object} filterObject {pickupDateStart, pickupDateEnd}
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var editOrdersAsync = exports.editOrdersAsync = function () {
  var _ref18 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee17() {
    var orderDataList = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var filterObject = arguments[1];
    var token = arguments[2];
    var updatedOrderDataList, url, pickupDateStart, pickupDateEnd, validationStatusId, response;
    return regeneratorRuntime.wrap(function _callee17$(_context17) {
      while (1) {
        switch (_context17.prev = _context17.next) {
          case 0:
            _context17.prev = 0;
            updatedOrderDataList = orderDataList.map(function (data) {
              var tmpObject = {
                order_id: data.orderId,
                order_data: (0, _ChangeCase.camelToSnake)(data.orderData)
              };
              return tmpObject;
            });
            url = '' + _Endpoint2.default.API_V3.ORDER;

            if (filterObject) {
              pickupDateStart = filterObject.pickupDateStart, pickupDateEnd = filterObject.pickupDateEnd, validationStatusId = filterObject.validationStatusId;

              url += '?pickup_date_start=' + pickupDateStart + '&pickup_date_end=' + pickupDateEnd + '&validation_status_id=' + validationStatusId;
            }

            _context17.next = 6;
            return (0, _axios2.default)({
              method: 'PUT',
              url: url,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: updatedOrderDataList
            });

          case 6:
            response = _context17.sent;
            return _context17.abrupt('return', (0, _camelize2.default)(response.data));

          case 10:
            _context17.prev = 10;
            _context17.t0 = _context17['catch'](0);
            return _context17.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context17.t0));

          case 13:
          case 'end':
            return _context17.stop();
        }
      }
    }, _callee17, undefined, [[0, 10]]);
  }));

  return function editOrdersAsync() {
    return _ref18.apply(this, arguments);
  };
}();

/**
 * Delete single order
 * @param {array} orderId
 * @param {string} token
 * @return {object} Promise resolve/reject
 * return {data: true} if deleting is success
 */
var deleteOrderAsync = exports.deleteOrderAsync = function () {
  var _ref19 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee18(orderId, token) {
    return regeneratorRuntime.wrap(function _callee18$(_context18) {
      while (1) {
        switch (_context18.prev = _context18.next) {
          case 0:
            _context18.prev = 0;
            _context18.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.ORDER + '/' + orderId,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context18.abrupt('return', { data: true });

          case 6:
            _context18.prev = 6;
            _context18.t0 = _context18['catch'](0);
            return _context18.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context18.t0));

          case 9:
          case 'end':
            return _context18.stop();
        }
      }
    }, _callee18, undefined, [[0, 6]]);
  }));

  return function deleteOrderAsync(_x40, _x41) {
    return _ref19.apply(this, arguments);
  };
}();

/**
 * Delete Multiple Orders
 * @param {array} orderIds
 * @param {string} token
 * @return {object} Promise resolve/reject
 * return {data: true} if deleting is success
 */
var deleteOrdersAsync = exports.deleteOrdersAsync = function () {
  var _ref20 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee19() {
    var orderIds = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var token = arguments[1];
    var paramString;
    return regeneratorRuntime.wrap(function _callee19$(_context19) {
      while (1) {
        switch (_context19.prev = _context19.next) {
          case 0:
            _context19.prev = 0;
            paramString = orderIds.join();
            _context19.next = 4;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.ORDER + '?order_ids=' + paramString,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            return _context19.abrupt('return', { data: true });

          case 7:
            _context19.prev = 7;
            _context19.t0 = _context19['catch'](0);
            return _context19.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context19.t0));

          case 10:
          case 'end':
            return _context19.stop();
        }
      }
    }, _callee19, undefined, [[0, 7]]);
  }));

  return function deleteOrdersAsync() {
    return _ref20.apply(this, arguments);
  };
}();

/**
 * Delete Multiple Orders
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 * return {data: true} if deleting is success
 */
var deleteAllOrdersAsync = exports.deleteAllOrdersAsync = function () {
  var _ref21 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee20(params, token) {
    return regeneratorRuntime.wrap(function _callee20$(_context20) {
      while (1) {
        switch (_context20.prev = _context20.next) {
          case 0:
            _context20.prev = 0;
            _context20.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: '' + _Endpoint2.default.API_V3.ORDER,
              headers: { Authorization: 'Bearer ' + token },
              params: params
            });

          case 3:
            return _context20.abrupt('return', { data: true });

          case 6:
            _context20.prev = 6;
            _context20.t0 = _context20['catch'](0);
            return _context20.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context20.t0));

          case 9:
          case 'end':
            return _context20.stop();
        }
      }
    }, _callee20, undefined, [[0, 6]]);
  }));

  return function deleteAllOrdersAsync(_x43, _x44) {
    return _ref21.apply(this, arguments);
  };
}();

/**
 * Group Orders with error contents
 * @param {object} orders
 * @param {object} errorContents
 * @return {object} { data: [0], groupId: [2]}
 */
var groupOrders = exports.groupOrders = function groupOrders(orders) {
  var errorContents = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

  var orderGroups = orders['data'].reduce(function (groupAddressObject, order, index) {
    return orderByPickUpAddress(groupAddressObject, order, errorContents);
  }, { data: [0], groupIds: [0] });

  if (typeof orderGroups['data'][0] === 'number') {
    orderGroups['data'].splice(0, 1);
  }

  var result = {
    totalLocationCount: orders['meta'].totalLocationCount, // total_location_count
    successLocationCount: orders['meta'].validatedLocationCount, // validated_location_count
    failedLocationCount: orders['meta'].failedLocationCount, // failed_location_count
    totalValidatedOrdersCount: orders['meta'].validatedOrdersWithoutRoutesCount, // total of routes with status created
    data: orderGroups.data
  };

  return result;
};

/**
 * Group Order by Pickup Address
 * @param {object} groups
 * @param {object} order
 * @param {object} errorContents The errorContent number.
 * @return {object} groupped addresses
 */
function orderByPickUpAddress(groups, order, errorContents) {
  // ErrorContents
  var groupId = order.pickupGroupId;
  var index = groups['groupIds'].indexOf(groupId);
  if (index === -1) {
    index = groupId ? groups['groupIds'].length : 0;
    if (index) groups['groupIds'].push(groupId);
  }

  if (!(groups['data'][index] instanceof Object)) {
    groups['data'][index] = {
      id: groupId,
      address: order.pickupLocationAddress,
      jobs: []
    };
  }

  // driver will be empty array if there's no driver info
  // Add avatarUrl as a empty string, this field will be included in response.
  (0, _lodash2.default)(order.driver) ? order.driver = {} : order.driver['avatarUrl'] = '';

  if (errorContents) {
    order.error = mergeLocationDataWithErrors(errorContents, order);
  }

  order.latitude = order.latitude || '';
  order.longitude = order.longitude || '';
  groups['data'][index]['jobs'].push(order);

  return groups;
}

/**
 * Merge Location data with Errors
 * @param {object} errorContents # Error object
 * @param {object} order # location object
 * @return {array} errorList
 * if there's no error for this location, it will response empty array.
 */
var mergeLocationDataWithErrors = exports.mergeLocationDataWithErrors = function mergeLocationDataWithErrors(errorContents, order) {
  var error = errorContents.data.find(function (errorContent) {
    return errorContent.orderId === order.id;
  });
  if (error) {
    return Object.keys(error['errorMessages']).reduce(function (errorList, key) {
      if (error['errorMessages'][key].length && key.search('Suggestion') === -1) {
        var includeSuggestionKey = error['errorMessages'][key] === ('pickupLocationAddress' || 'deliveryAddress');

        errorList.push({
          key: key,
          errorId: error['id'],
          suggestionKey: includeSuggestionKey ? ['latitude', 'longitude'] : [],
          suggestion: error['errorMessages'][key + 'Suggestion'] || '',
          errorMessage: error['errorMessages'][key]
        });
      }
      return errorList;
    }, []);
  }

  /* Response empty array if there's no error from dynamodb */
  return [];
};

/**
 * Update requested data
 * Example :
 {
    "type_id": 1,
    "order_ids": [
      1
    ]
 }
 * @param {object} requestData
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var updateOrderDispatchTo3PL = exports.updateOrderDispatchTo3PL = function () {
  var _ref22 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee21(requestData, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee21$(_context21) {
      while (1) {
        switch (_context21.prev = _context21.next) {
          case 0:
            _context21.prev = 0;
            _context21.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.DISPATCH_3PL,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: requestData
            });

          case 3:
            response = _context21.sent;
            return _context21.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context21.prev = 7;
            _context21.t0 = _context21['catch'](0);
            return _context21.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context21.t0));

          case 10:
          case 'end':
            return _context21.stop();
        }
      }
    }, _callee21, undefined, [[0, 7]]);
  }));

  return function updateOrderDispatchTo3PL(_x46, _x47) {
    return _ref22.apply(this, arguments);
  };
}();

/**
 * @param {object} requestData
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var broadcastToFreelancers = exports.broadcastToFreelancers = function () {
  var _ref23 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee22(requestData, token) {
    var result;
    return regeneratorRuntime.wrap(function _callee22$(_context22) {
      while (1) {
        switch (_context22.prev = _context22.next) {
          case 0:
            _context22.prev = 0;
            _context22.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: '' + _Endpoint2.default.API_V3.BROADCAST_TO_FREELANCERS,
              headers: { Authorization: 'Bearer ' + token },
              data: requestData
            });

          case 3:
            result = _context22.sent;
            return _context22.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context22.prev = 7;
            _context22.t0 = _context22['catch'](0);
            return _context22.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context22.t0));

          case 10:
          case 'end':
            return _context22.stop();
        }
      }
    }, _callee22, undefined, [[0, 7]]);
  }));

  return function broadcastToFreelancers(_x48, _x49) {
    return _ref23.apply(this, arguments);
  };
}();

/** Stop dispatching order
 * @param {int} orderId
 * @param {string} token
 * @return {Object} Promise resolve/reject
 * If resolve, return { data: true }
 //TODO: needs unit testing
 */
var deleteOrderDispatchAsync = exports.deleteOrderDispatchAsync = function () {
  var _ref24 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee23(orderId, token) {
    var result;
    return regeneratorRuntime.wrap(function _callee23$(_context23) {
      while (1) {
        switch (_context23.prev = _context23.next) {
          case 0:
            _context23.prev = 0;
            _context23.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.ORDER_ID.replace('{0}', orderId) + '/dispatch',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            result = _context23.sent;
            return _context23.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context23.prev = 7;
            _context23.t0 = _context23['catch'](0);
            return _context23.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context23.t0));

          case 10:
          case 'end':
            return _context23.stop();
        }
      }
    }, _callee23, undefined, [[0, 7]]);
  }));

  return function deleteOrderDispatchAsync(_x50, _x51) {
    return _ref24.apply(this, arguments);
  };
}();

/**
 * Retrieve Order Status reason
 * @param {int} statusId
 * @param {string} token
 * @return {object} Promise resolve/reject
 //TODO: needs more extensive unit testing
 */
var getOrderStatusReasonAsync = exports.getOrderStatusReasonAsync = function () {
  var _ref25 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee24(statusId, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee24$(_context24) {
      while (1) {
        switch (_context24.prev = _context24.next) {
          case 0:
            _context24.prev = 0;
            _context24.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ORDER_STATUS_REASON,
              headers: { Authorization: 'Bearer ' + token },
              params: { status_id: statusId }
            });

          case 3:
            response = _context24.sent;
            return _context24.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context24.prev = 7;
            _context24.t0 = _context24['catch'](0);
            return _context24.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context24.t0));

          case 10:
          case 'end':
            return _context24.stop();
        }
      }
    }, _callee24, undefined, [[0, 7]]);
  }));

  return function getOrderStatusReasonAsync(_x52, _x53) {
    return _ref25.apply(this, arguments);
  };
}();

/**
 * Update order status
 * Example :
 {
    "status_id": "11",
    "order_status_reason_id": 0,
    "notes": "string"
 }
 * @param {object} orderId
 * @param {object} payload
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var updateOrderStatus = exports.updateOrderStatus = function () {
  var _ref26 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee25(orderId, payload, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee25$(_context25) {
      while (1) {
        switch (_context25.prev = _context25.next) {
          case 0:
            _context25.prev = 0;
            _context25.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.ORDER_ID.replace('{0}', orderId) + '/status',
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: (0, _ChangeCase.camelToSnake)(payload)
            });

          case 3:
            response = _context25.sent;
            return _context25.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context25.prev = 7;
            _context25.t0 = _context25['catch'](0);
            return _context25.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context25.t0));

          case 10:
          case 'end':
            return _context25.stop();
        }
      }
    }, _callee25, undefined, [[0, 7]]);
  }));

  return function updateOrderStatus(_x54, _x55, _x56) {
    return _ref26.apply(this, arguments);
  };
}();

/**
 * Split order to multiple order
 * @param {object} orderId
 * @param {object} payload
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var splitToMultipleOrder = exports.splitToMultipleOrder = function () {
  var _ref27 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee26(orderId, payload, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee26$(_context26) {
      while (1) {
        switch (_context26.prev = _context26.next) {
          case 0:
            _context26.prev = 0;
            _context26.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.ORDER_ID.replace('{0}', orderId) + '/split',
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: (0, _ChangeCase.camelToSnake)(payload)
            });

          case 3:
            response = _context26.sent;
            return _context26.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context26.prev = 7;
            _context26.t0 = _context26['catch'](0);
            return _context26.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context26.t0));

          case 10:
          case 'end':
            return _context26.stop();
        }
      }
    }, _callee26, undefined, [[0, 7]]);
  }));

  return function splitToMultipleOrder(_x57, _x58, _x59) {
    return _ref27.apply(this, arguments);
  };
}();

/**
 * Generate order quote for service provider
 * @param {int} orderId
 * @param {string} customerEmail
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var generateOrderQuoteAsync = exports.generateOrderQuoteAsync = function () {
  var _ref28 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee27(orderId, customerEmail, params, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee27$(_context27) {
      while (1) {
        switch (_context27.prev = _context27.next) {
          case 0:
            _context27.prev = 0;
            _context27.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER_QUOTE,
              headers: { Authorization: 'Bearer ' + token },
              data: {
                order_data: (0, _ChangeCase.camelToSnake)(params),
                order_id: orderId,
                order_customer_email: customerEmail
              }
            });

          case 3:
            response = _context27.sent;
            return _context27.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context27.prev = 7;
            _context27.t0 = _context27['catch'](0);
            return _context27.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context27.t0));

          case 10:
          case 'end':
            return _context27.stop();
        }
      }
    }, _callee27, undefined, [[0, 7]]);
  }));

  return function generateOrderQuoteAsync(_x60, _x61, _x62, _x63) {
    return _ref28.apply(this, arguments);
  };
}();