'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addCustomerCredits = exports.getListOfDriverService = exports.searchServiceProviderCustomerAsync = exports.getServiceProviderAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _ChangeCase = require('../utility/ChangeCase');

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

/**
 * Retrieve Service Provider by id
 * @param {number} serviceProviderId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getServiceProviderAsync = exports.getServiceProviderAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(serviceProviderId, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER.replace('{0}', serviceProviderId),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function getServiceProviderAsync(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Search Service Provider customers
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var searchServiceProviderCustomerAsync = exports.searchServiceProviderCustomerAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(params, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER_CUSTOMER_SEARCH,
              headers: { Authorization: 'Bearer ' + token },
              params: params
            });

          case 3:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function searchServiceProviderCustomerAsync(_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Get list of drivers services
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getListOfDriverService = exports.getListOfDriverService = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(token) {
    var res;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER_DRIVER_SERVICES,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            res = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(res.data));

          case 7:
            _context3.prev = 7;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 10:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 7]]);
  }));

  return function getListOfDriverService(_x5) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Update customer credits
 * @param {object} params
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var addCustomerCredits = exports.addCustomerCredits = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(params, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.SERVICE_PROVIDER_CUSTOMER.replace('{0}', params.customerId) + '/credit',
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: (0, _ChangeCase.camelToSnake)(params.payload)
            });

          case 3:
            response = _context4.sent;
            return _context4.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context4.prev = 7;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 10:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 7]]);
  }));

  return function addCustomerCredits(_x6, _x7) {
    return _ref4.apply(this, arguments);
  };
}();