'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUserDateTimefromUTC = exports.getUserDateTimeInTimezone = exports.mergeArraysWithObjects = exports.customError = exports.hasSameObjectId = exports.getCSVStringFromArrayObject = exports.pushKeyAndMessageToArray = exports.arrayMap = exports.arrayReduce = exports.convertObjectIntoKeyValueArray = exports.getFormattedErrorArray = exports.rejectPromise = exports.apiResponseErrorHandler = exports.convertObjectIntoURLString = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }(); /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          * @fileoverview This file contains all general Utility functions
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          */

var _lodash = require('lodash.isobject');

var _lodash2 = _interopRequireDefault(_lodash);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _momentTimezone = require('moment-timezone');

var _momentTimezone2 = _interopRequireDefault(_momentTimezone);

var _lodash3 = require('lodash.get');

var _lodash4 = _interopRequireDefault(_lodash3);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Convert Object into string as URL params
 * Example: &limit=10&offset=20
 * @param {object} filters
 * @return {string} urlString
 */
var convertObjectIntoURLString = exports.convertObjectIntoURLString = function convertObjectIntoURLString(filters) {
  return Object.keys(filters).reduce(function (str, key) {
    return str += '&' + key + '=' + filters[key];
  }, '');
};

/**
 * Handle API Error
 * @param {object} e #error object
 * @return {object} Promise reject with statusCode and statusText
 */
var apiResponseErrorHandler = exports.apiResponseErrorHandler = function apiResponseErrorHandler(e) {
  var rejectObj = {};

  var messages = null;
  var response = e.response;

  if (response) {
    rejectObj.statusCode = e.response.status;
    rejectObj.statusText = e.response.statusText;
    if (response.data) {
      var message = response.data.message;

      rejectObj.message = message;
      if (response.data.errors) {
        var errors = [];
        var errorObj = e.response.data.errors;

        if (errorObj.location_data) {
          errorObj = errorObj.location_data;
        }
        var camelizedObj = (0, _camelize2.default)(errorObj);
        var keys = Object.keys(camelizedObj);
        keys.forEach(function (key) {
          errors.push({
            key: key,
            messages: camelizedObj[key]
          });
        });
        if (errors.length) {
          messages = errors;
        }
      }
    }

    rejectObj.errorMessage = messages || getFormattedErrorArray(e.response.data['Message']);
  } else if (e.statusCode) {
    rejectObj = e;
  } else {
    /* Catch error of e.response
    That will be undefined when status code is 403 Forbidden */
    rejectObj = { statusCode: 403, statusText: 'Forbidden', errorMessage: [] };
  }
  return Promise.reject(rejectObj);
};

/**
 * Response Promise Reject
 * It is for normal function rejection (not ajax call) to front-end
 * @param {object} e #error object
 * @return {object} Promise reject with statusCode and statusText
 */
var rejectPromise = exports.rejectPromise = function rejectPromise(e) {
  return Promise.reject({
    statusCode: e.statusCode,
    statusText: e.statusText,
    errorMessage: []
  });
};

/**
 * Format error messages into key value objects inside of array
 * @param {object} errorMessage #error object
 * @return {array} error array
 * If errorMessage is string,
 * return error string value as an element of array and key will be null value
 * Other wise, convert error objectes into key/value elements of an array.
 */
var getFormattedErrorArray = exports.getFormattedErrorArray = function getFormattedErrorArray(errorMessage) {
  if ((0, _lodash2.default)(errorMessage)) {
    return arrayReduce(convertObjectIntoKeyValueArray(errorMessage), pushKeyAndMessageToArray);
  }

  // return key as null, and pass errorMessage into string element of an array
  return [{
    key: null,
    messages: [errorMessage]
  }];
};

/**
 * Convert Object into key/value array.
 * ES6 Object.entries method will convert object into key, value array.
 * @param {object} object
 * @return {array} [key, value]
 */
var convertObjectIntoKeyValueArray = exports.convertObjectIntoKeyValueArray = function convertObjectIntoKeyValueArray(object) {
  // implementation of Object.entries as it is not available in all browsers
  var ownProps = Object.keys(object);
  var i = ownProps.length;
  var resArray = new Array(i); // preallocate the Array
  while (i--) {
    resArray[i] = [ownProps[i], object[ownProps[i]]];
  }
  return resArray;
};

/**
 * Iterate the array and format by using ES 6 reduce method
 * Javascript ES Object.entries method will convert object into key, value array.
 * @param {object} array
 * @param {object} cb #call back function
 * @param {array} accumulator
 * @return {array} reduced data array
 */
var arrayReduce = exports.arrayReduce = function arrayReduce(array, cb) {
  var accumulator = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

  return array.reduce(cb, accumulator);
};

/**
 * Iterate the array and format by using ES 6 reduce method
 * Javascript ES Object.entries method will convert object into key, value array.
 * @param {object} array
 * @param {object} cb #call back function
 * @param {array} accumulator
 * @return {array} reduced data array
 */
var arrayMap = exports.arrayMap = function arrayMap(array, cb) {
  return array.map(cb);
};

/**
 * Store key/value element into array
 * @param {array} newArray #error object
 * @param {array}} [key, value]
 * @return {array} new accumulator array
 */
var pushKeyAndMessageToArray = exports.pushKeyAndMessageToArray = function pushKeyAndMessageToArray(newArray, _ref) {
  var _ref2 = _slicedToArray(_ref, 2),
      key = _ref2[0],
      value = _ref2[1];

  newArray.push({ key: key, messages: value });
  return newArray;
};

/**
 * Manipulate the id of Array Object into CSV string
 * @param {object} array
 * @param {object} fieldName
 * @return {string} comma seperated value string
 */
var getCSVStringFromArrayObject = exports.getCSVStringFromArrayObject = function getCSVStringFromArrayObject(array, fieldName) {
  return array.map(function (data) {
    return data[fieldName];
  }).join();
};

/**
 * Find the the same id in the object
 * @param {array} a
 * @param {array} b
 * @return {boolean} true/falsea
 */
var hasSameObjectId = exports.hasSameObjectId = function hasSameObjectId(a, b) {
  return a.id === b.id;
};

/**
 * It creates error response from object
 * @param {Object} error {statusCode, status}
 * @return {Object} error object for errorHandler
 */
var customError = exports.customError = function customError(error) {
  return {
    response: {
      status: error.statusCode,
      statusText: error.statusText,
      data: {}
    }
  };
};

/**
 * It merges two similar arrays and merge specific property of object in this array.
 * @param {Array} a first array
 * @param {Array} b seconds array
 * @param {string} prop unique property what we comparing (ex. id)
 * @param {string} mergeProp property which we want to merge (ex. data array)
 * @return {Array} updatedArray
 */
var mergeArraysWithObjects = exports.mergeArraysWithObjects = function mergeArraysWithObjects() {
  var a = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var b = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var prop = arguments[2];
  var mergeProp = arguments[3];

  if (a.length === 0 && b.length === 0) {
    return [];
  }
  if (a.length === 0) {
    return [].concat(_toConsumableArray(b));
  }
  if (b.length === 0) {
    return [].concat(_toConsumableArray(a));
  }
  var updatedArray = a.map(function (aItem) {
    var item = b.find(function (bitem) {
      return bitem.id === aItem.id;
    });
    return item ? _extends({}, aItem, _defineProperty({}, mergeProp, [].concat(_toConsumableArray(aItem[mergeProp]), _toConsumableArray(item[mergeProp])))) : aItem;
  });

  b.forEach(function (bitem) {
    var uniqueIndex = updatedArray.findIndex(function (item) {
      return item.id === bitem.id;
    });
    if (uniqueIndex < 0) {
      updatedArray.push(bitem);
    }
  });

  return updatedArray;
};

/**
 * It takes moment() instance and convert it to the timezone where user is active depending on his identity. Then returns also moment() instance.
 * @param {Object} datetime datetime moment instance
 * @param {String} timezone timezone string name
 * @return {Object} moment instance which will have all moment methods
 * Example of usage:
 * getUserDateTimefromUTC(
 *  moment(),
 *  'Singapore',
 * ).format('YYYY-MM-DD HH:mm')
 */

var getUserDateTimeInTimezone = exports.getUserDateTimeInTimezone = function getUserDateTimeInTimezone(datetime, timezone) {
  if (datetime && timezone) {
    return datetime.tz(timezone);
  }
  return null;
};

/** DEPRECATED in favor of getUserDateTimeInTimezone
 * It takes UTC unix timestamp in seconds and convert it to the timezone where user is active depending on his identity.
 * timestamp, userIdentityId, identities
 * @param {Number} timestamp datetime unix timestamp in seconds
 * @param {Number} userIdentityId identity id of the user
 * @param {Array} identities collection of identities
 * @return {Object} moment instance which will have all moment methods
 * Example of usage:
 * getUserDateTimefromUTC(
 *  new Date.getTime() / 1000,
 *  1,
 *  [...identities...]
 * ).format('YYYY-MM-DD HH:mm')
 */

var getUserDateTimefromUTC = exports.getUserDateTimefromUTC = function getUserDateTimefromUTC(timestamp, userIdentityId, identities) {
  if (timestamp && userIdentityId && identities && identities.length) {
    var timezone = (0, _lodash4.default)(identities.find(function (i) {
      return i.id === userIdentityId;
    }), 'identityDetail.timezone', '');
    return (0, _momentTimezone2.default)(timestamp * 1000).tz(timezone);
  }
  return null;
};