'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pubsub = undefined;

var _ably = require('ably');

var Ably = _interopRequireWildcard(_ably);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

/**
 * Declare Pub/Sub (Ably)
 * @param {string} key
 * @param {string} channel
 * @param {boolean} realtime
 * @return {object} {publish, subscribe, unsubscribe, history}
 */
/**
 * @fileoverview This file contains all general messaging related functions that are triggered by various users
 */

var pubsub = exports.pubsub = function pubsub(key, channel) {
  var realtime = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

  var client = realtime ? new Ably.Realtime(key) : new Ably.Rest(key);
  var chan = client.channels.get(channel);
  return {
    publish: function publish(event, message) {
      chan.publish(event, (0, _camelize2.default)(message));
    },

    subscribe: function subscribe(event, callback) {
      chan.subscribe(event, function (message) {
        callback((0, _camelize2.default)(JSON.parse(message.data)));
      });
    },

    unsubscribe: function unsubscribe(event, listener) {
      chan.unsubscribe(event, listener);
    },

    history: function history(callback) {
      chan.history(callback);
    }
  };
};