'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.camelToSnake = exports.snakeToCamel = undefined;

var _lodash = require('lodash.isobject');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.isarray');

var _lodash4 = _interopRequireDefault(_lodash3);

var _lodash5 = require('lodash.isnumber');

var _lodash6 = _interopRequireDefault(_lodash5);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param {Object|String} data string or keys of object are named in form of snake
 * @param {number} depth to which level of keys should it process
 * @return {Object|String} string or keys of object are named in form of camel case
 */
var snakeToCamel = exports.snakeToCamel = function snakeToCamel(data, depth) {
  if ((0, _lodash2.default)(data) || (0, _lodash4.default)(data)) {
    if (typeof depth === 'undefined') {
      depth = 1;
    }
    return processKeys(data, camelize, depth);
  } else {
    return camelize(data);
  }
};

/**
 * @param {Object|String} data string or keys of object are named in form of camel case
 * @param {number} depth to which level of keys should it process
 * @return {Object|String} string or keys of object are named in form of snake
 */
/**
 * @fileoverview This file contains all general ChangeCasing functions
 */

var camelToSnake = exports.camelToSnake = function camelToSnake(data, depth) {
  if ((0, _lodash2.default)(data) || (0, _lodash4.default)(data)) {
    if (typeof depth === 'undefined') {
      depth = 1;
    }
    return processKeys(data, snakelize, depth);
  } else {
    return snakelize(data);
  }
};

/**
 * snakelize a string formed in underscore
 * @param {int/string} key The first param.
 * @return {string} key
 */
function snakelize(key) {
  var separator = '_';
  var split = /(?=[A-Z])/;

  return key.split(split).join(separator).toLowerCase();
}

/**
 * camelize a string formed in underscore
 * @param {int/string} key The frist number.
 * @return {string} key
 */
function camelize(key) {
  if ((0, _lodash6.default)(key)) {
    return key;
  }

  key = key.replace(/[\-_\s]+(.)?/g, function (match, ch) {
    return ch ? ch.toUpperCase() : '';
  });
  // Ensure 1st char is always lowercase
  return key.substr(0, 1).toLowerCase() + key.substr(1);
}

/**
 * camelize/snakelize keys of an object
 * depth to which level of keys should it process
 * @param {int} obj
 * @param {int} processer
 * @param {int} depth
 * @return {int} result
 */
function processKeys(obj, processer, depth) {
  if (depth === 0 || !(0, _lodash2.default)(obj)) {
    return obj;
  }

  var result = void 0;
  if ((0, _lodash2.default)(obj)) {
    result = {};
    var keys = Object.keys(obj);
    for (var i = 0; i < keys.length; i++) {
      result[processer(keys[i])] = processKeys(obj[keys[i]], processer, depth - 1);
    }
  } else {
    result = [];
    for (var _i = 0; _i < obj.length; _i++) {
      result[processer(_i)] = processKeys(obj[_i], processer, depth - 1);
    }
  }

  return result;
}