'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getUserNotificationCountAsync = exports.deleteUserNotificationAsync = exports.putUserNotification = exports.getUserNotificationsAsync = exports.deleteNotificationAsync = exports.getNotificationsAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all notification related functions that are triggered by a User
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Get Notification
 * @param {boolean} all true/false
 * true mean retrieve all notifications
 * @param {string} userId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getNotificationsAsync = exports.getNotificationsAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var all = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    var userId = arguments[1];
    var token = arguments[2];
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.NOTIFICATIONS.replace('{0}', userId) + '?all=' + all,
              headers: { Authorization: token }
            });

          case 3:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function getNotificationsAsync() {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Delete Notification
 * @param {int} notificationId
 * @param {string} userId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var deleteNotificationAsync = exports.deleteNotificationAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(notificationId, userId, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.NOTIFICATIONS.replace('{0}', userId) + '/' + notificationId,
              headers: { Authorization: token }
            });

          case 3:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function deleteNotificationAsync(_x2, _x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Get Notification
 * Example : next_cursor=1556612424880&limit=10&is_read=0
 * @param {object} filters
 * true mean retrieve all notifications
 * @param {string} userId
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var getUserNotificationsAsync = exports.getUserNotificationsAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(filters, userId, token) {
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)(filters);
            _context3.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.NOTIFICATIONS + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            response = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(response.data));

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 11:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 8]]);
  }));

  return function getUserNotificationsAsync(_x5, _x6, _x7) {
    return _ref3.apply(this, arguments);
  };
}();

/**
 * Update requested data
 * Example :
  [
    {
        "id": 1556612424880,
        "is_read": 1
    }
  ]
 * @param {object} requestData
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var putUserNotification = exports.putUserNotification = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(requestData, token) {
    var response;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.NOTIFICATIONS,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: requestData
            });

          case 3:
            response = _context4.sent;
            return _context4.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context4.prev = 7;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 10:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 7]]);
  }));

  return function putUserNotification(_x8, _x9) {
    return _ref4.apply(this, arguments);
  };
}();

/**
 * Delete Multiple Notifications
 * @param {array} notificationIds
 * @param {string} token
 * @return {object} Promise resolve/reject
 * return {data: true} if deleting is success
 */
var deleteUserNotificationAsync = exports.deleteUserNotificationAsync = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5() {
    var notificationIds = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var token = arguments[1];
    var paramString;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.prev = 0;
            paramString = notificationIds.join();
            _context5.next = 4;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.NOTIFICATIONS + '?ids=' + paramString,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            return _context5.abrupt('return', { data: true });

          case 7:
            _context5.prev = 7;
            _context5.t0 = _context5['catch'](0);
            return _context5.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context5.t0));

          case 10:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[0, 7]]);
  }));

  return function deleteUserNotificationAsync() {
    return _ref5.apply(this, arguments);
  };
}();

/**
 * Get notification counts
 * @param {string} token
 * @return {object} counts for read and unread notificaitons
 */
var getUserNotificationCountAsync = exports.getUserNotificationCountAsync = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(token) {
    var response;
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.prev = 0;
            _context6.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.NOTIFICATIONS_COUNT,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            response = _context6.sent;
            return _context6.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context6.prev = 7;
            _context6.t0 = _context6['catch'](0);
            return _context6.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context6.t0));

          case 10:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[0, 7]]);
  }));

  return function getUserNotificationCountAsync(_x11) {
    return _ref6.apply(this, arguments);
  };
}();