'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateResetPasswordTokenAsync = exports.resetPasswordAsync = exports.resetPasswordRequestAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all account related functions that are triggered by a User
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Request reset password token
 * @param {string} email
 * @return {object} Promise resolve/reject
 */
var resetPasswordRequestAsync = exports.resetPasswordRequestAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(email) {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.REQUEST_PASSWORD_RESET,
              headers: { 'Content-Type': 'application/json' },
              data: {
                email: email
              }
            });

          case 3:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function resetPasswordRequestAsync(_x) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Reset password with valid token
 * @param {string} token
 * @param {string} email
 * @param {string} password
 * @param {string} confirmPassword
 * @return {object} Promise resolve/reject
 */
var resetPasswordAsync = exports.resetPasswordAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(token, email, password, confirmPassword) {
    var response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.REQUEST_PASSWORD_RESET,
              headers: { 'Content-Type': 'application/json' },
              data: {
                token: token,
                email: email,
                password: password,
                password_confirmation: confirmPassword
              }
            });

          case 3:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function resetPasswordAsync(_x2, _x3, _x4, _x5) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Validate Reset Password Token
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var validateResetPasswordTokenAsync = exports.validateResetPasswordTokenAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(token) {
    var response;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.VALIDATE_PASSWORD_RESET_TOKEN.replace('{token}', token),
              headers: { 'Content-Type': 'application/json' },
              data: {
                token: token
              }
            });

          case 3:
            response = _context3.sent;
            return _context3.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 7:
            _context3.prev = 7;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 10:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 7]]);
  }));

  return function validateResetPasswordTokenAsync(_x6) {
    return _ref3.apply(this, arguments);
  };
}();