'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDispatchType = exports.getDispatchMode = exports.putCustomerSettings = exports.showCustomerSettingsAsync = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

var _ChangeCase = require('../utility/ChangeCase');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Settings related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/** Retrieve Customer"s Settings
 * @param {string} token
 * @return {Promise} settings object
 */

var showCustomerSettingsAsync = exports.showCustomerSettingsAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(token) {
    var CustomerSettingsShow;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.CUSTOMER_SETTINGS_SHOW,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            CustomerSettingsShow = _context.sent;
            return _context.abrupt('return', _extends({}, CustomerSettingsShow, {
              data: (0, _camelize2.default)(CustomerSettingsShow.data)
            }));

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 10:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 7]]);
  }));

  return function showCustomerSettingsAsync(_x) {
    return _ref.apply(this, arguments);
  };
}();

/** Updates the customer's settings.
 * @param {string} token
 * @param {int} id
 * @param {Object} data
 * @return {Promise} settings object
 */

var putCustomerSettings = exports.putCustomerSettings = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(token, id, data) {
    var response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: _Endpoint2.default.API_V3.CUSTOMER_SETTINGS.replace('{0}', id),
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _ChangeCase.camelToSnake)(data)
            });

          case 3:
            response = _context2.sent;
            return _context2.abrupt('return', _extends({}, response, {
              data: (0, _camelize2.default)(response.data)
            }));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function putCustomerSettings(_x2, _x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}();

/** Retrieve Dispatch Mode
 * @return {Promise} settings object
 */
var getDispatchMode = exports.getDispatchMode = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3() {
    var response;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.DISPATCH_MODE
            });

          case 3:
            response = _context3.sent;
            return _context3.abrupt('return', {
              data: (0, _camelize2.default)(response.data)
            });

          case 7:
            _context3.prev = 7;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 10:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 7]]);
  }));

  return function getDispatchMode() {
    return _ref3.apply(this, arguments);
  };
}();

/** Retrieve Dispatch Type
 * @return {Promise} settings object
 */
var getDispatchType = exports.getDispatchType = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4() {
    var response;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.DISPATCH_TYPE
            });

          case 3:
            response = _context4.sent;
            return _context4.abrupt('return', {
              data: (0, _camelize2.default)(response.data)
            });

          case 7:
            _context4.prev = 7;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 10:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 7]]);
  }));

  return function getDispatchType() {
    return _ref4.apply(this, arguments);
  };
}();