'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRouteDraftDetails = exports.getRouteLocationOrder = exports.getRouteAsync = exports.recalculateRouteOrder = exports.updateRoutedOrder = exports.removeRouteLocationsAsync = exports.updateRouteLocationAsync = exports.createRouteLocationAsync = exports.removeRouteAsync = exports.storeRouteAsync = exports.getRoutesAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

var _ChangeCase = require('../utility/ChangeCase');

var _lodash = require('lodash.toarray');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Routes related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/**
 * Get Routes
 * @param {object} filterObject # {pickupDate (mandatory), routeStatusIds, includeJobs, limit, page}
 * pickupDate (optional)(string) = "2018-02-28"
 * routeStatusIds (optional)(int) = 1,2 (csv)
 * includeJobs (optional)(bollean) = true/false
 * limit = 20 (optional)(int)
 * page = 0 (optional)(int)
 * @param {string} token
 * @return {object} Promise resolve/reject
 * @deprecated since version 0.3.1
 */
var getRoutesAsync = exports.getRoutesAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(filterObject, token) {
    var paramString, routes;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)((0, _ChangeCase.camelToSnake)(filterObject));
            _context.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ROUTE + paramString.replace('&', '?'),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 4:
            routes = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(routes.data));

          case 8:
            _context.prev = 8;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 8]]);
  }));

  return function getRoutesAsync(_x, _x2) {
    return _ref.apply(this, arguments);
  };
}();

/**
 * Create Routes
 * @param {object} payload
 * pickupDate (mandatory) (string),
 * driverId (optional) (int),
 * routeSettings (optional) (json string),
 * routeLocations (mandatory) (array),
 * sequence (mandatory) (int),
 * orderId (mandatory) (int)
 * locationTypeId  (mandatory) (int) (2 for Delivery Location or 3 for Pickup Location)
 * routeCapacity (optional) (decimal)
 * replaceAllExisting (boolean) (optional)
 Example payload
 {
    "routes": [
    {
       "driverId": 2,
       "pickupDate": "2018-03-30",
       "routeSettings": "{}",
       "routeLocations": [
         {
           "sequence": 1,
           "orderId": 1,
           "locationTypeId": 3,
           "routeCapacity": 10.5
         }
       ]
     }
   ],
   "replaceAllExisting": true
 }
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var storeRouteAsync = exports.storeRouteAsync = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(payload, token) {
    var routes;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.STORE_ROUTE,
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _ChangeCase.camelToSnake)(payload, 5)
            });

          case 3:
            routes = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(routes.data));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function storeRouteAsync(_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}();

/** Remove Route
 * @param {string} routeIds # string csv
 * @param {string} token
 * @return {object} Promise resolve/reject
 */
var removeRouteAsync = exports.removeRouteAsync = function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(routeIds, token) {
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.prev = 0;
            _context3.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: '' + _Endpoint2.default.API_V3.ROUTE.replace('{0}', '?route_ids=' + routeIds),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context3.abrupt('return', { data: true });

          case 6:
            _context3.prev = 6;
            _context3.t0 = _context3['catch'](0);
            return _context3.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context3.t0));

          case 9:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, undefined, [[0, 6]]);
  }));

  return function removeRouteAsync(_x5, _x6) {
    return _ref3.apply(this, arguments);
  };
}();

/** Create Route Location
 * @param {int} routeId
 * @param {array} payload [{sequence, groupingLocationId, locationTypeId}]
 * sequence (mandatory)(int)
 * groupingLocationId (optional)(int) eg. 1
 * locationTypeId (optional)(int) 2 for Delivery Location, 3 for Pickup Location
 * Exaple payload
 [
  {
    "sequence": 1,
    "groupingLocationId": 1,
    "locationTypeId": 3
  }
 ]
 * @param {string} token
 * @return {Object} Promise resolve/reject
 //TODO: needs unit testing
 */
var createRouteLocationAsync = exports.createRouteLocationAsync = function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(routeId) {
    var payload = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var token = arguments[2];
    var result;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.prev = 0;
            _context4.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: '' + _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId),
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _lodash2.default)((0, _ChangeCase.camelToSnake)(payload, 2))
            });

          case 3:
            result = _context4.sent;
            return _context4.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context4.prev = 7;
            _context4.t0 = _context4['catch'](0);
            return _context4.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context4.t0));

          case 10:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, undefined, [[0, 7]]);
  }));

  return function createRouteLocationAsync(_x8) {
    return _ref4.apply(this, arguments);
  };
}();

/** Update Route Location
 * @param {int} routeId
 * @param {array} payload
 * Example of palyload
 [
    {
        "routeLocationId": 4,
        "pickupWindowStart": "09:00",
        "pickupWindowEnd": "19:00"
    },
    {
        "routeLocationId": 8,
        "deliveryWindowStart": "09:00",
        "deliveryWindowEnd": "12:00"
    }
]
 * routeLocationId (mandatory)(int)
 * pickupWindowStart (mandatory)(string)
 * pickupWindowEnd (mandatory)(string)
 * deliveryWindowStart (mandatory)(string)
 * deliveryWindowEnd (mandatory)(string)
 * @param {string} token
 * @return {Object} Promise resolve/reject
 //TODO: needs unit testing
 */
var updateRouteLocationAsync = exports.updateRouteLocationAsync = function () {
  var _ref5 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(routeId) {
    var payload = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var token = arguments[2];
    var result;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.prev = 0;
            _context5.next = 3;
            return (0, _axios2.default)({
              method: 'PUT',
              url: '' + _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId),
              headers: { Authorization: 'Bearer ' + token },
              data: (0, _lodash2.default)((0, _ChangeCase.camelToSnake)(payload, 2))
            });

          case 3:
            result = _context5.sent;
            return _context5.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context5.prev = 7;
            _context5.t0 = _context5['catch'](0);
            return _context5.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context5.t0));

          case 10:
          case 'end':
            return _context5.stop();
        }
      }
    }, _callee5, undefined, [[0, 7]]);
  }));

  return function updateRouteLocationAsync(_x10) {
    return _ref5.apply(this, arguments);
  };
}();

/** Remove route schedule from driver
 * @param {int} routeId
 * @param {string} routeLocationIds # csv eg. 1,2,3
 * @param {string} token
 * @return {Object} Promise resolve/reject
 * If resolve, return { data: true }
 //TODO: needs unit testing
 */
var removeRouteLocationsAsync = exports.removeRouteLocationsAsync = function () {
  var _ref6 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(routeId, routeLocationIds, token) {
    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            _context6.prev = 0;
            _context6.next = 3;
            return (0, _axios2.default)({
              method: 'DELETE',
              url: _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId) + '?route_location_ids=' + routeLocationIds,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            return _context6.abrupt('return', { data: true });

          case 6:
            _context6.prev = 6;
            _context6.t0 = _context6['catch'](0);
            return _context6.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context6.t0));

          case 9:
          case 'end':
            return _context6.stop();
        }
      }
    }, _callee6, undefined, [[0, 6]]);
  }));

  return function removeRouteLocationsAsync(_x11, _x12, _x13) {
    return _ref6.apply(this, arguments);
  };
}();

/**
 * Update requested data
 * Example :
    {
      "pickup_time_window": "14:40-16:00",
      "delivery_time_window": "18:00-20:00",
      "delivery_address": "184 Jalan Toa Payoh, Singapore",
      "pickup_location_address": "184 Jalan Toa Payoh, Singapore",
      "pickup_coordinates": "1.3139961,103.7041625",
      "pickup_contact_name": "Joe Doe",
      "pickup_contact_company_name": "CarPal SG",
      "pickup_contact_email": "jdoe@carpal.me",
      "pickup_contact_phone": "+65999999",
      "delivery_contact_name": "Luke Walker",
      "delivery_contact_company_name": "LW Pte Ltd",
      "delivery_contact_email": "luke@walker.com",
      "delivery_contact_phone": "+65213123",
      "delivery_coordinates": "1.3139961,103.7041625",
      "delivery_notes": "Leave package at the door",
      "item_quantity": 2,
      "weight_per_item": 2,
      "item_description": "Cakes and stuff",
      "capacity": 1,
      "customer_order_number": "X-1234-9876",
      "cash_on_delivery_amount": "100.50"
    }
 * @param {array} requestData
 * @param {int} routeId
 * @param {int} routeLocationId
 * @param {int} orderId
 * @param {string} token
 * @return {Object} Promise resolve/reject
 * If resolve, return { data: true }
 */
var updateRoutedOrder = exports.updateRoutedOrder = function () {
  var _ref7 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7(requestData, routeId, routeLocationId, orderId, token) {
    var url, routes;
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.prev = 0;
            url = _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId) + '/' + routeLocationId + '/order/' + orderId;
            _context7.next = 4;
            return (0, _axios2.default)({
              method: 'PUT',
              url: url,
              headers: {
                Authorization: 'Bearer ' + token,
                'Content-Type': 'application/json'
              },
              data: {
                order_data: (0, _ChangeCase.camelToSnake)(requestData)
              }
            });

          case 4:
            routes = _context7.sent;
            return _context7.abrupt('return', (0, _camelize2.default)(routes.data));

          case 8:
            _context7.prev = 8;
            _context7.t0 = _context7['catch'](0);
            return _context7.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context7.t0));

          case 11:
          case 'end':
            return _context7.stop();
        }
      }
    }, _callee7, undefined, [[0, 8]]);
  }));

  return function updateRoutedOrder(_x14, _x15, _x16, _x17, _x18) {
    return _ref7.apply(this, arguments);
  };
}();

/**
 * Recalculate Order
 * @param {int} routeId
 * @param {string} token
 * @return {object} return recalculated route
 */
var recalculateRouteOrder = exports.recalculateRouteOrder = function () {
  var _ref8 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8(routeId, token) {
    var routes;
    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _context8.prev = 0;
            _context8.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.API_V3.ROUTE.replace('{0}', routeId) + '/recalculate',
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            routes = _context8.sent;
            return _context8.abrupt('return', (0, _camelize2.default)(routes.data));

          case 7:
            _context8.prev = 7;
            _context8.t0 = _context8['catch'](0);
            return _context8.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context8.t0));

          case 10:
          case 'end':
            return _context8.stop();
        }
      }
    }, _callee8, undefined, [[0, 7]]);
  }));

  return function recalculateRouteOrder(_x19, _x20) {
    return _ref8.apply(this, arguments);
  };
}();

/**
 * Recalculate Order
 * @param {int} routeId
 * @param {string} token
 * @return {object} return updated route
 */
var getRouteAsync = exports.getRouteAsync = function () {
  var _ref9 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9(routeId, token) {
    var routes;
    return regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.prev = 0;
            _context9.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.API_V3.ROUTE.replace('{0}', routeId),
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            routes = _context9.sent;
            return _context9.abrupt('return', (0, _camelize2.default)(routes.data));

          case 7:
            _context9.prev = 7;
            _context9.t0 = _context9['catch'](0);
            return _context9.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context9.t0));

          case 10:
          case 'end':
            return _context9.stop();
        }
      }
    }, _callee9, undefined, [[0, 7]]);
  }));

  return function getRouteAsync(_x21, _x22) {
    return _ref9.apply(this, arguments);
  };
}();

/**
 * Ger Route Location Order
 * @param {int} routeId
 * @param {int} routeLocationId
 * @param {string} token
 * @return {Object} Promise resolve/reject
 */
var getRouteLocationOrder = exports.getRouteLocationOrder = function () {
  var _ref10 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10(routeId, routeLocationId, token) {
    var result;
    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _context10.prev = 0;
            _context10.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId) + '/' + routeLocationId,
              headers: { Authorization: 'Bearer ' + token }
            });

          case 3:
            result = _context10.sent;
            return _context10.abrupt('return', (0, _camelize2.default)(result.data));

          case 7:
            _context10.prev = 7;
            _context10.t0 = _context10['catch'](0);
            return _context10.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context10.t0));

          case 10:
          case 'end':
            return _context10.stop();
        }
      }
    }, _callee10, undefined, [[0, 7]]);
  }));

  return function getRouteLocationOrder(_x23, _x24, _x25) {
    return _ref10.apply(this, arguments);
  };
}();

/**
 * Get route draft orders
 * @param {int} routeId
 * @param {int} routeLocationId
 * @param {int} orderId
 * @param {string} filterObj
 * @param {string} token
 * @return {object} return updated route
 */
var getRouteDraftDetails = exports.getRouteDraftDetails = function () {
  var _ref11 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11(routeId, routeLocationId, orderId, filterObj, token) {
    var routes;
    return regeneratorRuntime.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            _context11.prev = 0;
            _context11.next = 3;
            return (0, _axios2.default)({
              method: 'GET',
              url: _Endpoint2.default.API_V3.ROUTE_LOCATION.replace('{0}', routeId) + '/' + routeLocationId + '/order/' + orderId,
              headers: { Authorization: 'Bearer ' + token },
              params: (0, _ChangeCase.camelToSnake)(filterObj)
            });

          case 3:
            routes = _context11.sent;
            return _context11.abrupt('return', (0, _camelize2.default)(routes.data));

          case 7:
            _context11.prev = 7;
            _context11.t0 = _context11['catch'](0);
            return _context11.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context11.t0));

          case 10:
          case 'end':
            return _context11.stop();
        }
      }
    }, _callee11, undefined, [[0, 7]]);
  }));

  return function getRouteDraftDetails(_x26, _x27, _x28, _x29, _x30) {
    return _ref11.apply(this, arguments);
  };
}();