'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generalSearch = exports.searchAsync = undefined;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _Endpoint = require('../Endpoint');

var _Endpoint2 = _interopRequireDefault(_Endpoint);

var _camelize = require('camelize');

var _camelize2 = _interopRequireDefault(_camelize);

var _Util = require('../utility/Util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * @fileoverview This file contains all Search related functions that are triggered by a Customer
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */

/** Elastic Search
 * @param {string} keyword
 * @param {object} scope
 * @param {int} fuzzy
 * @param {int} fuzziness
 * @param {string} token
 * @return {object} Promise (resolve/reject)
 */
var searchAsync = exports.searchAsync = function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(keyword, scope) {
    var fuzzy = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    var fuzziness = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
    var token = arguments[4];
    var paramString, response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            paramString = (0, _Util.convertObjectIntoURLString)({
              keyword: keyword,
              fuzzy: fuzzy,
              fuzziness: fuzziness,
              scope: scope
            });
            _context.next = 4;
            return (0, _axios2.default)({
              method: 'GET',
              url: '' + _Endpoint2.default.ELASTIC_SEARCH + paramString.replace('&', '?'),
              headers: { Authorization: token }
            });

          case 4:
            response = _context.sent;
            return _context.abrupt('return', (0, _camelize2.default)(response.data.data));

          case 8:
            _context.prev = 8;
            _context.t0 = _context['catch'](0);
            return _context.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context.t0));

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined, [[0, 8]]);
  }));

  return function searchAsync(_x3, _x4) {
    return _ref.apply(this, arguments);
  };
}();

/** General Search
 * @param {int} customerId
 * @param {boolean} fuzzy
 * @param {int} fuzziness
 * @param {string} keywords
 * @param {object} scopes
 * There are 3 scopes # drivers, jobs, orders.
 * Can search any of these scope
 * Example of scopes object
   scopes = {
       "drivers" : ["driverId","driverName"],
       "jobs" : ["orderId"],
       "orders" : ["groupingLocationId"]
   }
 * @param {string} pickupDate (optional) # yyyy-mm-dd
 * @param {string} token
 * @return {object} response
 */
var generalSearch = exports.generalSearch = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(customerId) {
    var fuzzy = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    var fuzziness = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
    var keywords = arguments[3];
    var scopes = arguments[4];
    var pickupDate = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : '';
    var token = arguments[6];
    var response;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _axios2.default)({
              method: 'POST',
              url: _Endpoint2.default.GENERAL_SEARCH,
              headers: { Authorization: token },
              data: {
                customerId: customerId,
                fuzzy: fuzzy,
                fuzziness: fuzziness,
                keywords: keywords,
                scopes: scopes,
                pickupDate: pickupDate
              }
            });

          case 3:
            response = _context2.sent;
            return _context2.abrupt('return', (0, _camelize2.default)(response.data));

          case 7:
            _context2.prev = 7;
            _context2.t0 = _context2['catch'](0);
            return _context2.abrupt('return', (0, _Util.apiResponseErrorHandler)(_context2.t0));

          case 10:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined, [[0, 7]]);
  }));

  return function generalSearch(_x8) {
    return _ref2.apply(this, arguments);
  };
}();